@@ -1,29 +1,48 @@
+# /// script
+# requires-python = ">=3.9"
+# dependencies = [
+#     "flask",
+#     "flask-sqlalchemy>=3.1.1",
+#     "marshmallow",
+#     "sqlalchemy>2.0",
+# ]
+# ///
+from __future__ import annotations
+
 import datetime
 
 from flask import Flask, request
 from flask_sqlalchemy import SQLAlchemy
-from sqlalchemy.exc import IntegrityError
-from marshmallow import Schema, fields, ValidationError, pre_load
+from sqlalchemy.exc import NoResultFound
+from sqlalchemy.orm import DeclarativeBase, Mapped, mapped_column, relationship
+
+from marshmallow import Schema, ValidationError, fields, pre_load
 
 app = Flask(__name__)
 app.config["SQLALCHEMY_DATABASE_URI"] = "sqlite:////tmp/quotes.db"
-db = SQLAlchemy(app)
+
+
+class Base(DeclarativeBase):
+    pass
+
+
+db = SQLAlchemy(app, model_class=Base)
 
 ##### MODELS #####
 
 
-class Author(db.Model):  # type: ignore
-    id = db.Column(db.Integer, primary_key=True)
-    first = db.Column(db.String(80))
-    last = db.Column(db.String(80))
+class Author(db.Model):  # type: ignore[name-defined]
+    id: Mapped[int] = mapped_column(primary_key=True)
+    first: Mapped[str]
+    last: Mapped[str]
 
 
-class Quote(db.Model):  # type: ignore
-    id = db.Column(db.Integer, primary_key=True)
-    content = db.Column(db.String, nullable=False)
-    author_id = db.Column(db.Integer, db.ForeignKey("author.id"))
-    author = db.relationship("Author", backref=db.backref("quotes", lazy="dynamic"))
-    posted_at = db.Column(db.DateTime)
+class Quote(db.Model):  # type: ignore[name-defined]
+    id: Mapped[int] = mapped_column(primary_key=True)
+    content: Mapped[str] = mapped_column(nullable=False)
+    author_id: Mapped[int] = mapped_column(db.ForeignKey(Author.id))
+    author: Mapped[Author] = relationship(backref=db.backref("quotes", lazy="dynamic"))
+    posted_at: Mapped[datetime.datetime]
 
 
 ##### SCHEMAS #####
@@ -36,7 +55,7 @@ class AuthorSchema(Schema):
     formatted_name = fields.Method("format_name", dump_only=True)
 
     def format_name(self, author):
-        return "{}, {}".format(author.last, author.first)
+        return f"{author.last}, {author.first}"
 
 
 # Custom validator
@@ -58,7 +77,7 @@ class QuoteSchema(Schema):
         author_name = data.get("author")
         if author_name:
             first, last = author_name.split(" ")
-            author_dict = dict(first=first, last=last)
+            author_dict = {"first": first, "last": last}
         else:
             author_dict = {}
         data["author"] = author_dict
@@ -84,8 +103,8 @@ def get_authors():
 @app.route("/authors/<int:pk>")
 def get_author(pk):
     try:
-        author = Author.query.get(pk)
-    except IntegrityError:
+        author = Author.query.filter(Author.id == pk).one()
+    except NoResultFound:
         return {"message": "Author could not be found."}, 400
     author_result = author_schema.dump(author)
     quotes_result = quotes_schema.dump(author.quotes.all())
@@ -102,8 +121,8 @@ def get_quotes():
 @app.route("/quotes/<int:pk>")
 def get_quote(pk):
     try:
-        quote = Quote.query.get(pk)
-    except IntegrityError:
+        quote = Quote.query.filter(Quote.id == pk).one()
+    except NoResultFound:
         return {"message": "Quote could not be found."}, 400
     result = quote_schema.dump(quote)
     return {"quote": result}
@@ -127,7 +146,9 @@ def new_quote():
         db.session.add(author)
     # Create new quote
     quote = Quote(
-        content=data["content"], author=author, posted_at=datetime.datetime.utcnow()
+        content=data["content"],
+        author=author,
+        posted_at=datetime.datetime.now(datetime.UTC),
     )
     db.session.add(quote)
     db.session.commit()
@@ -136,5 +157,6 @@ def new_quote():
 
 
 if __name__ == "__main__":
-    db.create_all()
+    with app.app_context():
+        db.create_all()
     app.run(debug=True, port=5000)
