@@ -1,8 +1,17 @@
-import sys
+# /// script
+# requires-python = ">=3.9"
+# dependencies = [
+#     "marshmallow",
+#     "packaging>=17.0",
+# ]
+# ///
 import json
+import sys
+from pprint import pprint
+
 from packaging import version
 
-from marshmallow import Schema, fields, INCLUDE, pprint, ValidationError
+from marshmallow import INCLUDE, Schema, ValidationError, fields
 
 
 class Version(fields.Field):
@@ -11,8 +20,8 @@ class Version(fields.Field):
     def _deserialize(self, value, *args, **kwargs):
         try:
             return version.Version(value)
-        except version.InvalidVersion:
-            raise ValidationError("Not a valid version.")
+        except version.InvalidVersion as e:
+            raise ValidationError("Not a valid version.") from e
 
     def _serialize(self, value, *args, **kwargs):
         return str(value)
