@@ -1,30 +1,38 @@
 """Validation classes for various types of data."""
+
+from __future__ import annotations
+
 import re
+import typing
+import warnings
+from abc import ABC, abstractmethod
 from itertools import zip_longest
 from operator import attrgetter
-import typing
 
-from marshmallow import types
 from marshmallow.exceptions import ValidationError
+from marshmallow.warnings import ChangedInMarshmallow4Warning
+
+if typing.TYPE_CHECKING:
+    from marshmallow import types
+
+_T = typing.TypeVar("_T")
 
 
-class Validator:
-    """Base abstract class for validators.
+class Validator(ABC):
+    """Abstract base class for validators.
 
     .. note::
-        This class does not provide any behavior. It is only used to
+        This class does not provide any validation behavior. It is only used to
         add a useful `__repr__` implementation for validators.
     """
 
-    error = None  # type: typing.Optional[str]
+    error: str | None = None
 
     def __repr__(self) -> str:
         args = self._repr_args()
-        args = "{}, ".format(args) if args else ""
+        args = f"{args}, " if args else ""
 
-        return "<{self.__class__.__name__}({args}error={self.error!r})>".format(
-            self=self, args=args
-        )
+        return f"<{self.__class__.__name__}({args}error={self.error!r})>"
 
     def _repr_args(self) -> str:
         """A string representation of the args passed to this validator. Used by
@@ -32,11 +40,70 @@ class Validator:
         """
         return ""
 
+    @abstractmethod
+    def __call__(self, value: typing.Any) -> typing.Any: ...
+
+
+class And(Validator):
+    """Compose multiple validators and combine their error messages.
+
+    Example: ::
+
+        from marshmallow import validate, ValidationError
+
+
+        def is_even(value):
+            if value % 2 != 0:
+                raise ValidationError("Not an even value.")
+
+
+        validator = validate.And(validate.Range(min=0), is_even)
+        validator(-1)
+        # ValidationError: ['Must be greater than or equal to 0.', 'Not an even value.']
+
+    :param validators: Validators to combine.
+    :param error: Error message to use when a validator returns ``False``.
+    """
+
+    default_error_message = "Invalid value."
+
+    def __init__(self, *validators: types.Validator, error: str | None = None):
+        self.validators = tuple(validators)
+        self.error: str = error or self.default_error_message
+
+    def _repr_args(self) -> str:
+        return f"validators={self.validators!r}"
+
+    def __call__(self, value: typing.Any) -> typing.Any:
+        errors: list[str | dict] = []
+        kwargs: dict[str, typing.Any] = {}
+        for validator in self.validators:
+            try:
+                r = validator(value)
+                if not isinstance(validator, Validator) and r is False:
+                    warnings.warn(
+                        "Returning `False` from a validator is deprecated. "
+                        "Raise a `ValidationError` instead.",
+                        ChangedInMarshmallow4Warning,
+                        stacklevel=2,
+                    )
+                    raise ValidationError(self.error)  # noqa: TRY301
+            except ValidationError as err:
+                kwargs.update(err.kwargs)
+                if isinstance(err.messages, dict):
+                    errors.append(err.messages)
+                else:
+                    errors.extend(err.messages)
+        if errors:
+            raise ValidationError(errors, **kwargs)
+        return value
+
 
 class URL(Validator):
     """Validate a URL.
 
     :param relative: Whether to allow relative URLs.
+    :param absolute: Whether to allow absolute URLs.
     :param error: Error message to raise in case of a validation error.
         Can be interpolated with `{input}`.
     :param schemes: Valid schemes. By default, ``http``, ``https``,
@@ -48,38 +115,68 @@ class URL(Validator):
         def __init__(self):
             self._memoized = {}
 
-        def _regex_generator(self, relative: bool, require_tld: bool):
-            return re.compile(
-                r"".join(
-                    (
-                        r"^",
-                        r"(" if relative else r"",
-                        r"(?:[a-z0-9\.\-\+]*)://",  # scheme is validated separately
-                        r"(?:[^:@]+?(:[^:@]*?)?@|)",  # basic auth
-                        r"(?:(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+",
-                        r"(?:[A-Z]{2,6}\.?|[A-Z0-9-]{2,}\.?)|",  # domain...
-                        r"localhost|",  # localhost...
-                        (
-                            r"(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.?)|"
-                            if not require_tld
-                            else r""
-                        ),  # allow dotless hostnames
-                        r"\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}|",  # ...or ipv4
-                        r"\[[A-F0-9]*:[A-F0-9:]+\])",  # ...or ipv6
-                        r"(?::\d+)?",  # optional port
-                        r")?"
-                        if relative
-                        else r"",  # host is optional, allow for relative URLs
-                        r"(?:/?|[/?]\S+)$",
-                    )
+        def _regex_generator(
+            self, *, relative: bool, absolute: bool, require_tld: bool
+        ) -> typing.Pattern:
+            hostname_variants = [
+                # a normal domain name, expressed in [A-Z0-9] chars with hyphens allowed only in the middle
+                # note that the regex will be compiled with IGNORECASE, so these are upper and lowercase chars
+                (
+                    r"(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+"
+                    r"(?:[A-Z]{2,6}\.?|[A-Z0-9-]{2,}\.?)"
                 ),
-                re.IGNORECASE,
-            )
+                # or the special string 'localhost'
+                r"localhost",
+                # or IPv4
+                r"\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}",
+                # or IPv6
+                r"\[[A-F0-9]*:[A-F0-9:]+\]",
+            ]
+            if not require_tld:
+                # allow dotless hostnames
+                hostname_variants.append(r"(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.?)")
 
-        def __call__(self, relative: bool, require_tld: bool) -> typing.Pattern:
-            key = (relative, require_tld)
+            absolute_part = "".join(
+                (
+                    # scheme (e.g. 'https://', 'ftp://', etc)
+                    # this is validated separately against allowed schemes, so in the regex
+                    # we simply want to capture its existence
+                    r"(?:[a-z0-9\.\-\+]*)://",
+                    # userinfo, for URLs encoding authentication
+                    # e.g. 'ftp://foo:bar@ftp.example.org/'
+                    r"(?:(?:[a-z0-9\-._~!$&'()*+,;=:]|%[0-9a-f]{2})*@)?",
+                    # netloc, the hostname/domain part of the URL plus the optional port
+                    r"(?:",
+                    "|".join(hostname_variants),
+                    r")",
+                    r"(?::\d+)?",
+                )
+            )
+            relative_part = r"(?:/?|[/?]\S+)\Z"
+
+            if relative:
+                if absolute:
+                    parts: tuple[str, ...] = (
+                        r"^(",
+                        absolute_part,
+                        r")?",
+                        relative_part,
+                    )
+                else:
+                    parts = (r"^", relative_part)
+            else:
+                parts = (r"^", absolute_part, relative_part)
+
+            return re.compile("".join(parts), re.IGNORECASE)
+
+        def __call__(
+            self, *, relative: bool, absolute: bool, require_tld: bool
+        ) -> typing.Pattern:
+            key = (relative, absolute, require_tld)
             if key not in self._memoized:
-                self._memoized[key] = self._regex_generator(relative, require_tld)
+                self._memoized[key] = self._regex_generator(
+                    relative=relative, absolute=absolute, require_tld=require_tld
+                )
 
             return self._memoized[key]
 
@@ -92,35 +189,51 @@ class URL(Validator):
         self,
         *,
         relative: bool = False,
-        schemes: types.StrSequenceOrSet = None,
+        absolute: bool = True,
+        schemes: types.StrSequenceOrSet | None = None,
         require_tld: bool = True,
-        error: str = None
+        error: str | None = None,
     ):
+        if not relative and not absolute:
+            raise ValueError(
+                "URL validation cannot set both relative and absolute to False."
+            )
         self.relative = relative
-        self.error = error or self.default_message  # type: str
+        self.absolute = absolute
+        self.error: str = error or self.default_message
         self.schemes = schemes or self.default_schemes
         self.require_tld = require_tld
 
     def _repr_args(self) -> str:
-        return "relative={!r}".format(self.relative)
+        return f"relative={self.relative!r}, absolute={self.absolute!r}"
 
     def _format_error(self, value) -> str:
         return self.error.format(input=value)
 
-    def __call__(self, value) -> typing.Any:
+    def __call__(self, value: str) -> str:
         message = self._format_error(value)
         if not value:
             raise ValidationError(message)
 
         # Check first if the scheme is valid
+        scheme = None
         if "://" in value:
             scheme = value.split("://")[0].lower()
             if scheme not in self.schemes:
                 raise ValidationError(message)
 
-        regex = self._regex(self.relative, self.require_tld)
+        regex = self._regex(
+            relative=self.relative, absolute=self.absolute, require_tld=self.require_tld
+        )
 
-        if not regex.search(value):
+        # Hostname is optional for file URLS. If absent it means `localhost`.
+        # Fill it in for the validation if needed
+        if scheme == "file" and value.startswith("file:///"):
+            matched = regex.search(value.replace("file:///", "file://localhost/", 1))
+        else:
+            matched = regex.search(value)
+
+        if not matched:
             raise ValidationError(message)
 
         return value
@@ -134,19 +247,20 @@ class Email(Validator):
     """
 
     USER_REGEX = re.compile(
-        r"(^[-!#$%&'*+/=?^`{}|~\w]+(\.[-!#$%&'*+/=?^`{}|~\w]+)*$"  # dot-atom
+        r"(^[-!#$%&'*+/=?^`{}|~\w]+(\.[-!#$%&'*+/=?^`{}|~\w]+)*\Z"  # dot-atom
         # quoted-string
         r'|^"([\001-\010\013\014\016-\037!#-\[\]-\177]'
-        r'|\\[\001-\011\013\014\016-\177])*"$)',
+        r'|\\[\001-\011\013\014\016-\177])*"\Z)',
         re.IGNORECASE | re.UNICODE,
     )
 
     DOMAIN_REGEX = re.compile(
         # domain
-        r"(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+" r"(?:[A-Z]{2,6}|[A-Z0-9-]{2,})$"
+        r"(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+"
+        r"(?:[A-Z]{2,6}|[A-Z0-9-]{2,})\Z"
         # literal form, ipv4 address (SMTP 4.1.3)
         r"|^\[(25[0-5]|2[0-4]\d|[0-1]?\d?\d)"
-        r"(\.(25[0-5]|2[0-4]\d|[0-1]?\d?\d)){3}\]$",
+        r"(\.(25[0-5]|2[0-4]\d|[0-1]?\d?\d)){3}\]\Z",
         re.IGNORECASE | re.UNICODE,
     )
 
@@ -154,13 +268,13 @@ class Email(Validator):
 
     default_message = "Not a valid email address."
 
-    def __init__(self, *, error: str = None):
-        self.error = error or self.default_message  # type: str
+    def __init__(self, *, error: str | None = None):
+        self.error: str = error or self.default_message
 
-    def _format_error(self, value) -> typing.Any:
+    def _format_error(self, value: str) -> str:
         return self.error.format(input=value)
 
-    def __call__(self, value) -> typing.Any:
+    def __call__(self, value: str) -> str:
         message = self._format_error(value)
 
         if not value or "@" not in value:
@@ -215,12 +329,12 @@ class Range(Validator):
 
     def __init__(
         self,
-        min=None,
-        max=None,
+        min=None,  # noqa: A002
+        max=None,  # noqa: A002
         *,
         min_inclusive: bool = True,
         max_inclusive: bool = True,
-        error: str = None
+        error: str | None = None,
     ):
         self.min = min
         self.max = max
@@ -241,14 +355,12 @@ class Range(Validator):
         )
 
     def _repr_args(self) -> str:
-        return "min={!r}, max={!r}, min_inclusive={!r}, max_inclusive={!r}".format(
-            self.min, self.max, self.min_inclusive, self.max_inclusive
-        )
+        return f"min={self.min!r}, max={self.max!r}, min_inclusive={self.min_inclusive!r}, max_inclusive={self.max_inclusive!r}"
 
-    def _format_error(self, value, message: str) -> str:
+    def _format_error(self, value: _T, message: str) -> str:
         return (self.error or message).format(input=value, min=self.min, max=self.max)
 
-    def __call__(self, value) -> typing.Any:
+    def __call__(self, value: _T) -> _T:
         if self.min is not None and (
             value < self.min if self.min_inclusive else value <= self.min
         ):
@@ -264,6 +376,9 @@ class Range(Validator):
         return value
 
 
+_SizedT = typing.TypeVar("_SizedT", bound=typing.Sized)
+
+
 class Length(Validator):
     """Validator which succeeds if the value passed to it has a
     length between a minimum and maximum. Uses len(), so it
@@ -285,7 +400,12 @@ class Length(Validator):
     message_equal = "Length must be {equal}."
 
     def __init__(
-        self, min: int = None, max: int = None, *, equal: int = None, error: str = None
+        self,
+        min: int | None = None,  # noqa: A002
+        max: int | None = None,  # noqa: A002
+        *,
+        equal: int | None = None,
+        error: str | None = None,
     ):
         if equal is not None and any([min, max]):
             raise ValueError(
@@ -299,14 +419,14 @@ class Length(Validator):
         self.equal = equal
 
     def _repr_args(self) -> str:
-        return "min={!r}, max={!r}, equal={!r}".format(self.min, self.max, self.equal)
+        return f"min={self.min!r}, max={self.max!r}, equal={self.equal!r}"
 
-    def _format_error(self, value, message: str) -> str:
+    def _format_error(self, value: _SizedT, message: str) -> str:
         return (self.error or message).format(
             input=value, min=self.min, max=self.max, equal=self.equal
         )
 
-    def __call__(self, value) -> typing.Any:
+    def __call__(self, value: _SizedT) -> _SizedT:
         length = len(value)
 
         if self.equal is not None:
@@ -336,17 +456,17 @@ class Equal(Validator):
 
     default_message = "Must be equal to {other}."
 
-    def __init__(self, comparable, *, error: str = None):
+    def __init__(self, comparable, *, error: str | None = None):
         self.comparable = comparable
-        self.error = error or self.default_message  # type: str
+        self.error: str = error or self.default_message
 
     def _repr_args(self) -> str:
-        return "comparable={!r}".format(self.comparable)
+        return f"comparable={self.comparable!r}"
 
-    def _format_error(self, value) -> str:
+    def _format_error(self, value: _T) -> str:
         return self.error.format(input=value, other=self.comparable)
 
-    def __call__(self, value) -> typing.Any:
+    def __call__(self, value: _T) -> _T:
         if value != self.comparable:
             raise ValidationError(self._format_error(value))
         return value
@@ -371,23 +491,29 @@ class Regexp(Validator):
 
     def __init__(
         self,
-        regex: typing.Union[str, bytes, typing.Pattern],
-        flags=0,
+        regex: str | bytes | typing.Pattern,
+        flags: int = 0,
         *,
-        error: str = None
+        error: str | None = None,
     ):
         self.regex = (
             re.compile(regex, flags) if isinstance(regex, (str, bytes)) else regex
         )
-        self.error = error or self.default_message  # type: str
+        self.error: str = error or self.default_message
 
     def _repr_args(self) -> str:
-        return "regex={!r}".format(self.regex)
+        return f"regex={self.regex!r}"
 
-    def _format_error(self, value) -> str:
+    def _format_error(self, value: str | bytes) -> str:
         return self.error.format(input=value, regex=self.regex.pattern)
 
-    def __call__(self, value) -> typing.Any:
+    @typing.overload
+    def __call__(self, value: str) -> str: ...
+
+    @typing.overload
+    def __call__(self, value: bytes) -> bytes: ...
+
+    def __call__(self, value):
         if self.regex.match(value) is None:
             raise ValidationError(self._format_error(value))
 
@@ -408,18 +534,18 @@ class Predicate(Validator):
 
     default_message = "Invalid input."
 
-    def __init__(self, method: str, *, error: str = None, **kwargs):
+    def __init__(self, method: str, *, error: str | None = None, **kwargs):
         self.method = method
-        self.error = error or self.default_message  # type: str
+        self.error: str = error or self.default_message
         self.kwargs = kwargs
 
     def _repr_args(self) -> str:
-        return "method={!r}, kwargs={!r}".format(self.method, self.kwargs)
+        return f"method={self.method!r}, kwargs={self.kwargs!r}"
 
-    def _format_error(self, value) -> str:
+    def _format_error(self, value: typing.Any) -> str:
         return self.error.format(input=value, method=self.method)
 
-    def __call__(self, value) -> str:
+    def __call__(self, value: _T) -> _T:
         method = getattr(value, self.method)
 
         if not method(**self.kwargs):
@@ -438,18 +564,18 @@ class NoneOf(Validator):
 
     default_message = "Invalid input."
 
-    def __init__(self, iterable: typing.Iterable, *, error: str = None):
+    def __init__(self, iterable: typing.Iterable, *, error: str | None = None):
         self.iterable = iterable
         self.values_text = ", ".join(str(each) for each in self.iterable)
-        self.error = error or self.default_message  # type: str
+        self.error: str = error or self.default_message
 
     def _repr_args(self) -> str:
-        return "iterable={!r}".format(self.iterable)
+        return f"iterable={self.iterable!r}"
 
     def _format_error(self, value) -> str:
         return self.error.format(input=value, values=self.values_text)
 
-    def __call__(self, value) -> str:
+    def __call__(self, value: typing.Any) -> typing.Any:
         try:
             if value in self.iterable:
                 raise ValidationError(self._format_error(value))
@@ -473,25 +599,25 @@ class OneOf(Validator):
     def __init__(
         self,
         choices: typing.Iterable,
-        labels: typing.Iterable[str] = None,
+        labels: typing.Iterable[str] | None = None,
         *,
-        error: str = None
+        error: str | None = None,
     ):
         self.choices = choices
         self.choices_text = ", ".join(str(choice) for choice in self.choices)
         self.labels = labels if labels is not None else []
         self.labels_text = ", ".join(str(label) for label in self.labels)
-        self.error = error or self.default_message  # type: str
+        self.error: str = error or self.default_message
 
     def _repr_args(self) -> str:
-        return "choices={!r}, labels={!r}".format(self.choices, self.labels)
+        return f"choices={self.choices!r}, labels={self.labels!r}"
 
     def _format_error(self, value) -> str:
         return self.error.format(
             input=value, choices=self.choices_text, labels=self.labels_text
         )
 
-    def __call__(self, value) -> str:
+    def __call__(self, value: typing.Any) -> typing.Any:
         try:
             if value not in self.choices:
                 raise ValidationError(self._format_error(value))
@@ -502,8 +628,8 @@ class OneOf(Validator):
 
     def options(
         self,
-        valuegetter: typing.Union[str, typing.Callable[[typing.Any], typing.Any]] = str,
-    ) -> typing.Iterable[typing.Tuple[typing.Any, str]]:
+        valuegetter: str | typing.Callable[[typing.Any], typing.Any] = str,
+    ) -> typing.Iterable[tuple[typing.Any, str]]:
         """Return a generator over the (value, label) pairs, where value
         is a string associated with each choice. This convenience method
         is useful to populate, for instance, a form select field.
@@ -525,9 +651,9 @@ class ContainsOnly(OneOf):
     in the sequence is also in the sequence passed as ``choices``. Empty input
     is considered valid.
 
-    :param iterable choices: Same as :class:`OneOf`.
-    :param iterable labels: Same as :class:`OneOf`.
-    :param str error: Same as :class:`OneOf`.
+    :param choices: Same as :class:`OneOf`.
+    :param labels: Same as :class:`OneOf`.
+    :param error: Same as :class:`OneOf`.
 
     .. versionchanged:: 3.0.0b2
         Duplicate values are considered valid.
@@ -542,9 +668,33 @@ class ContainsOnly(OneOf):
         value_text = ", ".join(str(val) for val in value)
         return super()._format_error(value_text)
 
-    def __call__(self, value) -> typing.Any:
+    def __call__(self, value: typing.Sequence[_T]) -> typing.Sequence[_T]:
         # We can't use set.issubset because does not handle unhashable types
         for val in value:
             if val not in self.choices:
                 raise ValidationError(self._format_error(value))
         return value
+
+
+class ContainsNoneOf(NoneOf):
+    """Validator which fails if ``value`` is a sequence and any element
+    in the sequence is a member of the sequence passed as ``iterable``. Empty input
+    is considered valid.
+
+    :param iterable: Same as :class:`NoneOf`.
+    :param error: Same as :class:`NoneOf`.
+
+    .. versionadded:: 3.6.0
+    """
+
+    default_message = "One or more of the choices you made was in: {values}."
+
+    def _format_error(self, value) -> str:
+        value_text = ", ".join(str(val) for val in value)
+        return super()._format_error(value_text)
+
+    def __call__(self, value: typing.Sequence[_T]) -> typing.Sequence[_T]:
+        for val in value:
+            if val in self.iterable:
+                raise ValidationError(self._format_error(value))
+        return value
