@@ -1,10 +1,10 @@
-from collections import OrderedDict
 import datetime as dt
+from collections import OrderedDict
 
 import pytest
 
-from marshmallow import fields, Schema, EXCLUDE
-
+from marshmallow import EXCLUDE, Schema, fields
+from marshmallow.warnings import RemovedInMarshmallow4Warning
 from tests.base import User
 
 
@@ -60,6 +60,19 @@ class OrderedNestedOnly(Schema):
 
 
 class TestFieldOrdering:
+    def test_ordered_option_is_deprecate(self):
+        with pytest.warns(RemovedInMarshmallow4Warning):
+
+            class MySchema(Schema):
+                class Meta:
+                    ordered = True
+
+        with pytest.warns(RemovedInMarshmallow4Warning):
+
+            class MySchema(Schema):
+                class Meta:
+                    ordered = False
+
     @pytest.mark.parametrize("with_meta", (False, True))
     def test_ordered_option_is_inherited(self, user, with_meta):
         class ParentUnordered(Schema):
@@ -178,9 +191,6 @@ class TestFieldOrdering:
 
     def test_nested_field_order_with_exclude_arg_is_maintained(self, user):
         class HasNestedExclude(Schema):
-            class Meta:
-                ordered = True
-
             user = fields.Nested(KeepOrder, exclude=("birthdate",))
 
         ser = HasNestedExclude()
@@ -231,20 +241,17 @@ class TestIncludeOption:
         result = s.load({"name": "Steve", "from": "Oskosh"})
         assert result == in_data
 
-    def test_ordered_included(self):
+    def test_included_fields_ordered_after_declared_fields(self):
         class AddFieldsOrdered(Schema):
             name = fields.Str()
             email = fields.Str()
 
             class Meta:
-                include = OrderedDict(
-                    [
-                        ("from", fields.Str()),
-                        ("in", fields.Str()),
-                        ("@at", fields.Str()),
-                    ]
-                )
-                ordered = True
+                include = {
+                    "from": fields.Str(),
+                    "in": fields.Str(),
+                    "@at": fields.Str(),
+                }
 
         s = AddFieldsOrdered()
         in_data = {
@@ -266,6 +273,22 @@ class TestIncludeOption:
             email = fields.Str()
 
         s = AddFieldsChild()
-        assert "email" in s._declared_fields.keys()
-        assert "from" in s._declared_fields.keys()
+        assert "email" in s._declared_fields
+        assert "from" in s._declared_fields
         assert isinstance(s._declared_fields["from"], fields.Str)
+
+
+class TestManyOption:
+    class ManySchema(Schema):
+        foo = fields.Str()
+
+        class Meta:
+            many = True
+
+    def test_many_by_default(self):
+        test = self.ManySchema()
+        assert test.load([{"foo": "bar"}]) == [{"foo": "bar"}]
+
+    def test_explicit_single(self):
+        test = self.ManySchema(many=False)
+        assert test.load({"foo": "bar"}) == {"foo": "bar"}
