@@ -1,6 +1,6 @@
 import pytest
 
-from marshmallow import Schema, fields, class_registry
+from marshmallow import Schema, class_registry, fields
 from marshmallow.exceptions import RegistryError
 
 
@@ -14,7 +14,7 @@ def test_serializer_has_class_registry():
     assert "MySchema" in class_registry._registry
     assert "MySubSchema" in class_registry._registry
 
-    #  by fullpath
+    # by fullpath
     assert "tests.test_registry.MySchema" in class_registry._registry
     assert "tests.test_registry.MySubSchema" in class_registry._registry
 
@@ -52,7 +52,6 @@ def test_register_class_meta_option():
 
 
 def test_serializer_class_registry_register_same_classname_different_module():
-
     reglen = len(class_registry._registry)
 
     type("MyTestRegSchema", (Schema,), {"__module__": "modA"})
@@ -60,30 +59,29 @@ def test_serializer_class_registry_register_same_classname_different_module():
     assert "MyTestRegSchema" in class_registry._registry
     assert len(class_registry._registry.get("MyTestRegSchema")) == 1
     assert "modA.MyTestRegSchema" in class_registry._registry
-    #  storing for classname and fullpath
+    # storing for classname and fullpath
     assert len(class_registry._registry) == reglen + 2
 
     type("MyTestRegSchema", (Schema,), {"__module__": "modB"})
 
     assert "MyTestRegSchema" in class_registry._registry
-    #  aggregating classes with same name from different modules
+    # aggregating classes with same name from different modules
     assert len(class_registry._registry.get("MyTestRegSchema")) == 2
     assert "modB.MyTestRegSchema" in class_registry._registry
-    #  storing for same classname (+0) and different module (+1)
+    # storing for same classname (+0) and different module (+1)
     assert len(class_registry._registry) == reglen + 2 + 1
 
     type("MyTestRegSchema", (Schema,), {"__module__": "modB"})
 
     assert "MyTestRegSchema" in class_registry._registry
-    #  only the class with matching module has been replaced
+    # only the class with matching module has been replaced
     assert len(class_registry._registry.get("MyTestRegSchema")) == 2
     assert "modB.MyTestRegSchema" in class_registry._registry
-    #  only the class with matching module has been replaced (+0)
+    # only the class with matching module has been replaced (+0)
     assert len(class_registry._registry) == reglen + 2 + 1
 
 
 def test_serializer_class_registry_override_if_same_classname_same_module():
-
     reglen = len(class_registry._registry)
 
     type("MyTestReg2Schema", (Schema,), {"__module__": "SameModulePath"})
@@ -92,18 +90,18 @@ def test_serializer_class_registry_override_if_same_classname_same_module():
     assert len(class_registry._registry.get("MyTestReg2Schema")) == 1
     assert "SameModulePath.MyTestReg2Schema" in class_registry._registry
     assert len(class_registry._registry.get("SameModulePath.MyTestReg2Schema")) == 1
-    #  storing for classname and fullpath
+    # storing for classname and fullpath
     assert len(class_registry._registry) == reglen + 2
 
     type("MyTestReg2Schema", (Schema,), {"__module__": "SameModulePath"})
 
     assert "MyTestReg2Schema" in class_registry._registry
-    #  overriding same class name and same module
+    # overriding same class name and same module
     assert len(class_registry._registry.get("MyTestReg2Schema")) == 1
     assert "SameModulePath.MyTestReg2Schema" in class_registry._registry
-    #  overriding same fullpath
+    # overriding same fullpath
     assert len(class_registry._registry.get("SameModulePath.MyTestReg2Schema")) == 1
-    #  overriding for same classname (+0) and different module (+0)
+    # overriding for same classname (+0) and different module (+0)
     assert len(class_registry._registry) == reglen + 2
 
 
@@ -127,17 +125,17 @@ class C:
 
 class ASchema(Schema):
     id = fields.Integer()
-    b = fields.Nested("BSchema", exclude=("a",))
+    b = fields.Nested("tests.test_registry.BSchema", exclude=("a",))
 
 
 class BSchema(Schema):
     id = fields.Integer()
-    a = fields.Nested("ASchema")
+    a = fields.Nested("tests.test_registry.ASchema")
 
 
 class CSchema(Schema):
     id = fields.Integer()
-    bs = fields.Nested("BSchema", many=True)
+    bs = fields.Nested("tests.test_registry.BSchema", many=True)
 
 
 def test_two_way_nesting():
@@ -176,7 +174,7 @@ class FooSerializer(Schema):
 
 def test_multiple_classes_with_same_name_raises_error():
     # Import a class with the same name
-    from .foo_serializer import FooSerializer as FooSerializer1  # noqa
+    from .foo_serializer import FooSerializer as FooSerializer1  # noqa: F401
 
     class MySchema(Schema):
         foo = fields.Nested("FooSerializer")
@@ -191,14 +189,14 @@ def test_multiple_classes_with_same_name_raises_error():
 
 def test_multiple_classes_with_all():
     # Import a class with the same name
-    from .foo_serializer import FooSerializer as FooSerializer1  # noqa
+    from .foo_serializer import FooSerializer as FooSerializer1  # noqa: F401
 
     classes = class_registry.get_class("FooSerializer", all=True)
     assert len(classes) == 2
 
 
 def test_can_use_full_module_path_to_class():
-    from .foo_serializer import FooSerializer as FooSerializer1  # noqa
+    from .foo_serializer import FooSerializer as FooSerializer1  # noqa: F401
 
     # Using full paths is ok
 
