@@ -1,52 +1,55 @@
 import datetime as dt
 import decimal
-import random
 import math
-from collections import namedtuple, OrderedDict
-
-import simplejson as json
+import random
+from collections import OrderedDict
+from typing import NamedTuple
 
 import pytest
+import simplejson as json
 
 from marshmallow import (
+    EXCLUDE,
+    INCLUDE,
+    RAISE,
     Schema,
+    class_registry,
     fields,
     utils,
     validates,
     validates_schema,
-    EXCLUDE,
-    INCLUDE,
-    RAISE,
-    class_registry,
 )
 from marshmallow.exceptions import (
-    ValidationError,
-    StringNotCollectionError,
     RegistryError,
+    StringNotCollectionError,
+    ValidationError,
+)
+from marshmallow.warnings import (
+    ChangedInMarshmallow4Warning,
+    RemovedInMarshmallow4Warning,
 )
-
 from tests.base import (
-    UserSchema,
-    UserMetaSchema,
-    UserRelativeUrlSchema,
-    ExtendedUserSchema,
-    UserIntSchema,
-    UserFloatStringSchema,
-    BlogSchema,
-    BlogUserMetaSchema,
+    Blog,
     BlogOnlySchema,
-    UserExcludeSchema,
-    UserAdditionalSchema,
+    BlogSchema,
     BlogSchemaExclude,
     BlogSchemaMeta,
+    BlogUserMetaSchema,
+    ExtendedUserSchema,
     User,
+    UserAdditionalSchema,
+    UserExcludeSchema,
+    UserFloatStringSchema,
+    UserIntSchema,
+    UserMetaSchema,
+    UserRelativeUrlSchema,
+    UserSchema,
     mockjson,
-    Blog,
 )
 
-
 random.seed(1)
 
+
 # Run tests with both verbose serializer and 'meta' option serializer
 @pytest.mark.parametrize("SchemaClass", [UserSchema, UserMetaSchema])
 def test_serializing_basic_object(SchemaClass, user):
@@ -83,25 +86,23 @@ def test_load_resets_errors():
 def test_load_validation_error_stores_input_data_and_valid_data():
     class MySchema(Schema):
         always_valid = fields.DateTime()
-        always_invalid = fields.Field(validate=[lambda v: False])
+        always_invalid = fields.Raw(validate=[lambda v: False])
 
     schema = MySchema()
     input_data = {
-        "always_valid": dt.datetime.utcnow().isoformat(),
+        "always_valid": dt.datetime.now(dt.timezone.utc).isoformat(),
         "always_invalid": 24,
     }
-    try:
+    with pytest.raises(ValidationError) as excinfo:
         schema.load(input_data)
-    except ValidationError as err:
-        # err.data is the raw input data
-        assert err.data == input_data
-        assert "always_valid" in err.valid_data
-        # err.valid_data contains valid, deserialized data
-        assert isinstance(err.valid_data["always_valid"], dt.datetime)
-        # excludes invalid data
-        assert "always_invalid" not in err.valid_data
-    else:
-        pytest.fail("Data is invalid. Expected a ValidationError to be raised.")
+    err = excinfo.value
+    # err.data is the raw input data
+    assert err.data == input_data
+    assert "always_valid" in err.valid_data
+    # err.valid_data contains valid, deserialized data
+    assert isinstance(err.valid_data["always_valid"], dt.datetime)
+    # excludes invalid data
+    assert "always_invalid" not in err.valid_data
 
 
 def test_load_resets_error_fields():
@@ -161,6 +162,16 @@ def test_dump_many():
     assert data[0] == s.dump(u1)
 
 
+@pytest.mark.parametrize("value", [[], {}, [1], {1: 1}])
+def test_boolean_can_dump_unhashable(value):
+    class MySchema(Schema):
+        has_items = fields.Boolean()
+
+    schema = MySchema()
+    data = schema.dump({"has_items": value})
+    assert data["has_items"] is bool(value)
+
+
 def test_multiple_errors_can_be_stored_for_a_given_index():
     class MySchema(Schema):
         foo = fields.Str(validate=lambda x: len(x) > 3)
@@ -180,19 +191,19 @@ def test_multiple_errors_can_be_stored_for_a_given_index():
 def test_dump_returns_a_dict(user):
     s = UserSchema()
     result = s.dump(user)
-    assert type(result) == dict
+    assert type(result) is dict
 
 
 def test_dumps_returns_a_string(user):
     s = UserSchema()
     result = s.dumps(user)
-    assert type(result) == str
+    assert type(result) is str
 
 
 def test_dumping_single_object_with_collection_schema(user):
     s = UserSchema(many=True)
     result = s.dump(user, many=False)
-    assert type(result) == dict
+    assert type(result) is dict
     assert result == UserSchema().dump(user)
 
 
@@ -200,7 +211,7 @@ def test_loading_single_object_with_collection_schema():
     s = UserSchema(many=True)
     in_data = {"name": "Mick", "email": "mick@stones.com"}
     result = s.load(in_data, many=False)
-    assert type(result) == User
+    assert type(result) is User
     assert result.name == UserSchema().load(in_data).name
 
 
@@ -216,15 +227,15 @@ def test_dumps_many():
 def test_load_returns_an_object():
     s = UserSchema()
     result = s.load({"name": "Monty"})
-    assert type(result) == User
+    assert type(result) is User
 
 
 def test_load_many():
     s = UserSchema()
     in_data = [{"name": "Mick"}, {"name": "Keith"}]
     result = s.load(in_data, many=True)
-    assert type(result) == list
-    assert type(result[0]) == User
+    assert type(result) is list
+    assert type(result[0]) is User
     assert result[0].name == "Mick"
 
 
@@ -292,7 +303,7 @@ def test_load_many_in_nested_empty_collection(val):
 def test_loads_returns_a_user():
     s = UserSchema()
     result = s.loads(json.dumps({"name": "Monty"}))
-    assert type(result) == User
+    assert type(result) is User
 
 
 def test_loads_many():
@@ -300,7 +311,7 @@ def test_loads_many():
     in_data = [{"name": "Mick"}, {"name": "Keith"}]
     in_json_data = json.dumps(in_data)
     result = s.loads(in_json_data, many=True)
-    assert type(result) == list
+    assert type(result) is list
     assert result[0].name == "Mick"
 
 
@@ -315,7 +326,7 @@ def test_loads_deserializes_from_json():
 
 def test_serializing_none():
     class MySchema(Schema):
-        id = fields.Str(default="no-id")
+        id = fields.Str(dump_default="no-id")
         num = fields.Int()
         name = fields.Str()
 
@@ -356,11 +367,12 @@ def test_nested_on_bind_field_hook():
 
         foo = fields.Nested(NestedSchema)
 
-    schema1 = MySchema(context={"fname": "foobar"})
-    schema2 = MySchema(context={"fname": "quxquux"})
+    with pytest.warns(RemovedInMarshmallow4Warning):
+        schema1 = MySchema(context={"fname": "foobar"})
+        schema2 = MySchema(context={"fname": "quxquux"})
 
-    assert schema1.fields["foo"].schema.fields["bar"].metadata["fname"] == "foobar"
-    assert schema2.fields["foo"].schema.fields["bar"].metadata["fname"] == "quxquux"
+        assert schema1.fields["foo"].schema.fields["bar"].metadata["fname"] == "foobar"
+        assert schema2.fields["foo"].schema.fields["bar"].metadata["fname"] == "quxquux"
 
 
 class TestValidate:
@@ -408,7 +420,7 @@ class TestValidate:
 
     def test_validate_required(self):
         class MySchema(Schema):
-            foo = fields.Field(required=True)
+            foo = fields.Raw(required=True)
 
         s = MySchema()
         errors = s.validate({"bar": 42})
@@ -427,7 +439,7 @@ def test_dumps_returns_json(user):
     ser = UserSchema()
     serialized = ser.dump(user)
     json_data = ser.dumps(user)
-    assert type(json_data) == str
+    assert type(json_data) is str
     expected = json.dumps(serialized)
     assert json_data == expected
 
@@ -519,14 +531,14 @@ def test_stored_invalid_email():
 def test_integer_field():
     u = User("John", age=42.3)
     serialized = UserIntSchema().dump(u)
-    assert type(serialized["age"]) == int
+    assert type(serialized["age"]) is int
     assert serialized["age"] == 42
 
 
 def test_as_string():
     u = User("John", age=42.3)
     serialized = UserFloatStringSchema().dump(u)
-    assert type(serialized["age"]) == str
+    assert type(serialized["age"]) is str
     assert math.isclose(float(serialized["age"]), 42.3)
 
 
@@ -545,7 +557,9 @@ def test_fields_must_be_declared_as_instances(user):
     class BadUserSchema(Schema):
         name = fields.String
 
-    with pytest.raises(TypeError, match="must be declared as a Field instance"):
+    with pytest.raises(
+        TypeError, match='Field for "name" must be declared as a Field instance'
+    ):
         BadUserSchema().dump(user)
 
 
@@ -630,11 +644,6 @@ def test_can_serialize_time(user, serialized_user):
     assert serialized_user["time_registered"] == expected
 
 
-def test_invalid_dict_but_okay():
-    u = User("Joe", various_data="baddict")
-    UserSchema().dump(u)
-
-
 def test_json_module_is_deprecated():
     with pytest.deprecated_call():
 
@@ -810,8 +819,8 @@ def test_nested_custom_set_in_exclude_reusing_schema():
             return [][item]
 
     class ChildSchema(Schema):
-        foo = fields.Field(required=True)
-        bar = fields.Field()
+        foo = fields.Raw(required=True)
+        bar = fields.Raw()
 
         class Meta:
             only = ("bar",)
@@ -828,13 +837,13 @@ def test_nested_custom_set_in_exclude_reusing_schema():
 
 def test_nested_only():
     class ChildSchema(Schema):
-        foo = fields.Field()
-        bar = fields.Field()
-        baz = fields.Field()
+        foo = fields.Raw()
+        bar = fields.Raw()
+        baz = fields.Raw()
 
     class ParentSchema(Schema):
-        bla = fields.Field()
-        bli = fields.Field()
+        bla = fields.Raw()
+        bli = fields.Raw()
         blubb = fields.Nested(ChildSchema)
 
     sch = ParentSchema(only=("bla", "blubb.foo", "blubb.bar"))
@@ -851,13 +860,13 @@ def test_nested_only():
 
 def test_nested_only_inheritance():
     class ChildSchema(Schema):
-        foo = fields.Field()
-        bar = fields.Field()
-        baz = fields.Field()
+        foo = fields.Raw()
+        bar = fields.Raw()
+        baz = fields.Raw()
 
     class ParentSchema(Schema):
-        bla = fields.Field()
-        bli = fields.Field()
+        bla = fields.Raw()
+        bli = fields.Raw()
         blubb = fields.Nested(ChildSchema, only=("foo", "bar"))
 
     sch = ParentSchema(only=("blubb.foo", "blubb.baz"))
@@ -874,13 +883,13 @@ def test_nested_only_inheritance():
 
 def test_nested_only_empty_inheritance():
     class ChildSchema(Schema):
-        foo = fields.Field()
-        bar = fields.Field()
-        baz = fields.Field()
+        foo = fields.Raw()
+        bar = fields.Raw()
+        baz = fields.Raw()
 
     class ParentSchema(Schema):
-        bla = fields.Field()
-        bli = fields.Field()
+        bla = fields.Raw()
+        bli = fields.Raw()
         blubb = fields.Nested(ChildSchema, only=("bar",))
 
     sch = ParentSchema(only=("blubb.foo",))
@@ -897,13 +906,13 @@ def test_nested_only_empty_inheritance():
 
 def test_nested_exclude():
     class ChildSchema(Schema):
-        foo = fields.Field()
-        bar = fields.Field()
-        baz = fields.Field()
+        foo = fields.Raw()
+        bar = fields.Raw()
+        baz = fields.Raw()
 
     class ParentSchema(Schema):
-        bla = fields.Field()
-        bli = fields.Field()
+        bla = fields.Raw()
+        bli = fields.Raw()
         blubb = fields.Nested(ChildSchema)
 
     sch = ParentSchema(exclude=("bli", "blubb.baz"))
@@ -920,13 +929,13 @@ def test_nested_exclude():
 
 def test_nested_exclude_inheritance():
     class ChildSchema(Schema):
-        foo = fields.Field()
-        bar = fields.Field()
-        baz = fields.Field()
+        foo = fields.Raw()
+        bar = fields.Raw()
+        baz = fields.Raw()
 
     class ParentSchema(Schema):
-        bla = fields.Field()
-        bli = fields.Field()
+        bla = fields.Raw()
+        bli = fields.Raw()
         blubb = fields.Nested(ChildSchema, exclude=("baz",))
 
     sch = ParentSchema(exclude=("blubb.foo",))
@@ -943,13 +952,13 @@ def test_nested_exclude_inheritance():
 
 def test_nested_only_and_exclude():
     class ChildSchema(Schema):
-        foo = fields.Field()
-        bar = fields.Field()
-        baz = fields.Field()
+        foo = fields.Raw()
+        bar = fields.Raw()
+        baz = fields.Raw()
 
     class ParentSchema(Schema):
-        bla = fields.Field()
-        bli = fields.Field()
+        bla = fields.Raw()
+        bli = fields.Raw()
         blubb = fields.Nested(ChildSchema)
 
     sch = ParentSchema(only=("bla", "blubb.foo", "blubb.bar"), exclude=("blubb.foo",))
@@ -966,13 +975,13 @@ def test_nested_only_and_exclude():
 
 def test_nested_only_then_exclude_inheritance():
     class ChildSchema(Schema):
-        foo = fields.Field()
-        bar = fields.Field()
-        baz = fields.Field()
+        foo = fields.Raw()
+        bar = fields.Raw()
+        baz = fields.Raw()
 
     class ParentSchema(Schema):
-        bla = fields.Field()
-        bli = fields.Field()
+        bla = fields.Raw()
+        bli = fields.Raw()
         blubb = fields.Nested(ChildSchema, only=("foo", "bar"))
 
     sch = ParentSchema(exclude=("blubb.foo",))
@@ -989,13 +998,13 @@ def test_nested_only_then_exclude_inheritance():
 
 def test_nested_exclude_then_only_inheritance():
     class ChildSchema(Schema):
-        foo = fields.Field()
-        bar = fields.Field()
-        baz = fields.Field()
+        foo = fields.Raw()
+        bar = fields.Raw()
+        baz = fields.Raw()
 
     class ParentSchema(Schema):
-        bla = fields.Field()
-        bli = fields.Field()
+        bla = fields.Raw()
+        bli = fields.Raw()
         blubb = fields.Nested(ChildSchema, exclude=("foo",))
 
     sch = ParentSchema(only=("blubb.bar",))
@@ -1012,15 +1021,15 @@ def test_nested_exclude_then_only_inheritance():
 
 def test_nested_exclude_and_only_inheritance():
     class ChildSchema(Schema):
-        foo = fields.Field()
-        bar = fields.Field()
-        baz = fields.Field()
-        ban = fields.Field()
-        fuu = fields.Field()
+        foo = fields.Raw()
+        bar = fields.Raw()
+        baz = fields.Raw()
+        ban = fields.Raw()
+        fuu = fields.Raw()
 
     class ParentSchema(Schema):
-        bla = fields.Field()
-        bli = fields.Field()
+        bla = fields.Raw()
+        bli = fields.Raw()
         blubb = fields.Nested(
             ChildSchema, only=("foo", "bar", "baz", "ban"), exclude=("foo",)
         )
@@ -1098,13 +1107,13 @@ def test_nested_instance_exclude():
 
 def test_meta_nested_exclude():
     class ChildSchema(Schema):
-        foo = fields.Field()
-        bar = fields.Field()
-        baz = fields.Field()
+        foo = fields.Raw()
+        bar = fields.Raw()
+        baz = fields.Raw()
 
     class ParentSchema(Schema):
-        bla = fields.Field()
-        bli = fields.Field()
+        bla = fields.Raw()
+        bli = fields.Raw()
         blubb = fields.Nested(ChildSchema)
 
         class Meta:
@@ -1160,9 +1169,9 @@ def test_nested_custom_set_not_implementing_getitem():
         Implements an object with some attribute
         """
 
-        def __init__(self, attribute):
+        def __init__(self, attribute: str):
             """
-            :param str attribute: The attribute to initialize
+            :param attribute: The attribute to initialize
             """
             self.attribute = attribute
 
@@ -1191,18 +1200,18 @@ def test_nested_custom_set_not_implementing_getitem():
 
 def test_deeply_nested_only_and_exclude():
     class GrandChildSchema(Schema):
-        goo = fields.Field()
-        gah = fields.Field()
-        bah = fields.Field()
+        goo = fields.Raw()
+        gah = fields.Raw()
+        bah = fields.Raw()
 
     class ChildSchema(Schema):
-        foo = fields.Field()
-        bar = fields.Field()
+        foo = fields.Raw()
+        bar = fields.Raw()
         flubb = fields.Nested(GrandChildSchema)
 
     class ParentSchema(Schema):
-        bla = fields.Field()
-        bli = fields.Field()
+        bla = fields.Raw()
+        bli = fields.Raw()
         blubb = fields.Nested(ChildSchema)
 
     sch = ParentSchema(
@@ -1276,10 +1285,10 @@ def test_nested_lambda():
 @pytest.mark.parametrize("data_key", ("f1", "f5", None))
 def test_data_key_collision(data_key):
     class MySchema(Schema):
-        f1 = fields.Field()
-        f2 = fields.Field(data_key=data_key)
-        f3 = fields.Field(data_key="f5")
-        f4 = fields.Field(data_key="f1", load_only=True)
+        f1 = fields.Raw()
+        f2 = fields.Raw(data_key=data_key)
+        f3 = fields.Raw(data_key="f5")
+        f4 = fields.Raw(data_key="f1", load_only=True)
 
     if data_key is None:
         MySchema()
@@ -1291,10 +1300,10 @@ def test_data_key_collision(data_key):
 @pytest.mark.parametrize("attribute", ("f1", "f5", None))
 def test_attribute_collision(attribute):
     class MySchema(Schema):
-        f1 = fields.Field()
-        f2 = fields.Field(attribute=attribute)
-        f3 = fields.Field(attribute="f5")
-        f4 = fields.Field(attribute="f1", dump_only=True)
+        f1 = fields.Raw()
+        f2 = fields.Raw(attribute=attribute)
+        f3 = fields.Raw(attribute="f5")
+        f4 = fields.Raw(attribute="f1", dump_only=True)
 
     if attribute is None:
         MySchema()
@@ -1304,7 +1313,7 @@ def test_attribute_collision(attribute):
 
 
 class TestDeeplyNestedLoadOnly:
-    @pytest.fixture()
+    @pytest.fixture
     def schema(self):
         class GrandChildSchema(Schema):
             str_dump_only = fields.String()
@@ -1336,7 +1345,7 @@ class TestDeeplyNestedLoadOnly:
             ),
         )
 
-    @pytest.fixture()
+    @pytest.fixture
     def data(self):
         return dict(
             str_dump_only="Dump Only",
@@ -1384,7 +1393,7 @@ class TestDeeplyNestedLoadOnly:
 
 
 class TestDeeplyNestedListLoadOnly:
-    @pytest.fixture()
+    @pytest.fixture
     def schema(self):
         class ChildSchema(Schema):
             str_dump_only = fields.String()
@@ -1402,7 +1411,7 @@ class TestDeeplyNestedListLoadOnly:
             load_only=("str_load_only", "child.str_load_only"),
         )
 
-    @pytest.fixture()
+    @pytest.fixture
     def data(self):
         return dict(
             str_dump_only="Dump Only",
@@ -1440,18 +1449,18 @@ class TestDeeplyNestedListLoadOnly:
 
 def test_nested_constructor_only_and_exclude():
     class GrandChildSchema(Schema):
-        goo = fields.Field()
-        gah = fields.Field()
-        bah = fields.Field()
+        goo = fields.Raw()
+        gah = fields.Raw()
+        bah = fields.Raw()
 
     class ChildSchema(Schema):
-        foo = fields.Field()
-        bar = fields.Field()
+        foo = fields.Raw()
+        bar = fields.Raw()
         flubb = fields.Nested(GrandChildSchema)
 
     class ParentSchema(Schema):
-        bla = fields.Field()
-        bli = fields.Field()
+        bla = fields.Raw()
+        bli = fields.Raw()
         blubb = fields.Nested(
             ChildSchema, only=("foo", "flubb.goo", "flubb.gah"), exclude=("flubb.goo",)
         )
@@ -1474,9 +1483,9 @@ def test_nested_constructor_only_and_exclude():
 
 def test_only_and_exclude():
     class MySchema(Schema):
-        foo = fields.Field()
-        bar = fields.Field()
-        baz = fields.Field()
+        foo = fields.Raw()
+        bar = fields.Raw()
+        baz = fields.Raw()
 
     sch = MySchema(only=("foo", "bar"), exclude=("bar",))
     data = dict(foo=42, bar=24, baz=242)
@@ -1487,7 +1496,7 @@ def test_only_and_exclude():
 
 def test_only_and_exclude_with_fields():
     class MySchema(Schema):
-        foo = fields.Field()
+        foo = fields.Raw()
 
         class Meta:
             fields = ("bar", "baz")
@@ -1501,7 +1510,7 @@ def test_only_and_exclude_with_fields():
 
 def test_invalid_only_and_exclude_with_fields():
     class MySchema(Schema):
-        foo = fields.Field()
+        foo = fields.Raw()
 
         class Meta:
             fields = ("bar", "baz")
@@ -1516,7 +1525,7 @@ def test_invalid_only_and_exclude_with_fields():
 
 def test_only_and_exclude_with_additional():
     class MySchema(Schema):
-        foo = fields.Field()
+        foo = fields.Raw()
 
         class Meta:
             additional = ("bar", "baz")
@@ -1530,7 +1539,7 @@ def test_only_and_exclude_with_additional():
 
 def test_invalid_only_and_exclude_with_additional():
     class MySchema(Schema):
-        foo = fields.Field()
+        foo = fields.Raw()
 
         class Meta:
             additional = ("bar", "baz")
@@ -1545,7 +1554,7 @@ def test_invalid_only_and_exclude_with_additional():
 
 def test_exclude_invalid_attribute():
     class MySchema(Schema):
-        foo = fields.Field()
+        foo = fields.Raw()
 
     with pytest.raises(ValueError, match="'bar'"):
         MySchema(exclude=("bar",))
@@ -1571,7 +1580,7 @@ def test_only_bounded_by_additional():
 
 def test_only_empty():
     class MySchema(Schema):
-        foo = fields.Field()
+        foo = fields.Raw()
 
     sch = MySchema(only=())
     assert "foo" not in sch.dump({"foo": "bar"})
@@ -1580,7 +1589,7 @@ def test_only_empty():
 @pytest.mark.parametrize("param", ("only", "exclude"))
 def test_only_and_exclude_as_string(param):
     class MySchema(Schema):
-        foo = fields.Field()
+        foo = fields.Raw()
 
     with pytest.raises(StringNotCollectionError):
         MySchema(**{param: "foo"})
@@ -1588,15 +1597,17 @@ def test_only_and_exclude_as_string(param):
 
 def test_nested_with_sets():
     class Inner(Schema):
-        foo = fields.Field()
+        foo = fields.Raw()
 
     class Outer(Schema):
         inners = fields.Nested(Inner, many=True)
 
     sch = Outer()
 
-    DataClass = namedtuple("DataClass", ["foo"])
-    data = dict(inners={DataClass(42), DataClass(2)})
+    class Thing(NamedTuple):
+        foo: int
+
+    data = dict(inners={Thing(42), Thing(2)})
     result = sch.dump(data)
     assert len(result["inners"]) == 2
 
@@ -1616,22 +1627,22 @@ def test_meta_serializer_fields():
 def test_meta_fields_mapping(user):
     s = UserMetaSchema()
     s.dump(user)  # need to call dump to update fields
-    assert type(s.fields["balance"]) == fields.Decimal
+    assert type(s.fields["balance"]) is fields.Decimal
     # Inferred fields
-    assert type(s.fields["name"]._field_cache[fields.String]) == fields.String
-    assert type(s.fields["created"]._field_cache[fields.DateTime]) == fields.DateTime
-    assert type(s.fields["updated"]._field_cache[fields.DateTime]) == fields.DateTime
-    assert type(s.fields["age"]._field_cache[fields.Float]) == fields.Float
-    assert type(s.fields["registered"]._field_cache[fields.Boolean]) == fields.Boolean
-    assert type(s.fields["sex_choices"]._field_cache[fields.Raw]) == fields.Raw
-    assert type(s.fields["hair_colors"]._field_cache[fields.Raw]) == fields.Raw
-    assert type(s.fields["finger_count"]._field_cache[fields.Integer]) == fields.Integer
-    assert type(s.fields["uid"]._field_cache[fields.UUID]) == fields.UUID
-    assert type(s.fields["time_registered"]._field_cache[fields.Time]) == fields.Time
-    assert type(s.fields["birthdate"]._field_cache[fields.Date]) == fields.Date
+    assert type(s.fields["name"]._field_cache[fields.String]) is fields.String
+    assert type(s.fields["created"]._field_cache[fields.DateTime]) is fields.DateTime
+    assert type(s.fields["updated"]._field_cache[fields.DateTime]) is fields.DateTime
+    assert type(s.fields["age"]._field_cache[fields.Float]) is fields.Float
+    assert type(s.fields["registered"]._field_cache[fields.Boolean]) is fields.Boolean
+    assert type(s.fields["sex_choices"]._field_cache[fields.Raw]) is fields.Raw
+    assert type(s.fields["hair_colors"]._field_cache[fields.Raw]) is fields.Raw
+    assert type(s.fields["finger_count"]._field_cache[fields.Integer]) is fields.Integer
+    assert type(s.fields["uid"]._field_cache[fields.UUID]) is fields.UUID
+    assert type(s.fields["time_registered"]._field_cache[fields.Time]) is fields.Time
+    assert type(s.fields["birthdate"]._field_cache[fields.Date]) is fields.Date
     assert (
         type(s.fields["since_created"]._field_cache[fields.TimeDelta])
-        == fields.TimeDelta
+        is fields.TimeDelta
     )
 
 
@@ -1700,6 +1711,22 @@ def test_dateformat_option(user):
     assert serialized["activation_date"] == user.activation_date.strftime(fmt)
 
 
+def test_timeformat_option(user):
+    fmt = "%H:%M:%S"
+    field_fmt = "%H:%M"
+
+    class TimeFormatSchema(Schema):
+        birthtime = fields.Time(field_fmt)
+
+        class Meta:
+            fields = ("birthtime", "time_registered")
+            timeformat = fmt
+
+    serialized = TimeFormatSchema().dump(user)
+    assert serialized["birthtime"] == user.birthtime.strftime(field_fmt)
+    assert serialized["time_registered"] == user.time_registered.strftime(fmt)
+
+
 def test_default_dateformat(user):
     class DateFormatSchema(Schema):
         updated = fields.DateTime(format="%m-%d")
@@ -1872,7 +1899,7 @@ class TestFieldValidation:
             raise ValidationError(["err1", "err2"])
 
         class MySchema(Schema):
-            foo = fields.Field(validate=validator)
+            foo = fields.Raw(validate=validator)
 
         s = MySchema()
         errors = s.validate({"foo": 42})
@@ -1884,7 +1911,7 @@ class TestFieldValidation:
             raise ValidationError({"code": "invalid_foo"})
 
         class MySchema(Schema):
-            foo = fields.Field(validate=validator)
+            foo = fields.Raw(validate=validator)
 
         s = MySchema()
         errors = s.validate({"foo": 42})
@@ -1892,8 +1919,8 @@ class TestFieldValidation:
 
     def test_ignored_if_not_in_only(self):
         class MySchema(Schema):
-            a = fields.Field()
-            b = fields.Field()
+            a = fields.Raw()
+            b = fields.Raw()
 
             @validates("a")
             def validate_a(self, val):
@@ -1927,13 +1954,12 @@ class TestNestedSchema:
     def blog(self, user):
         col1 = User(name="Mick", age=123)
         col2 = User(name="Keith", age=456)
-        blog = Blog(
+        return Blog(
             "Monty's blog",
             user=user,
             categories=["humor", "violence"],
             collaborators=[col1, col2],
         )
-        return blog
 
     # regression test for https://github.com/marshmallow-code/marshmallow/issues/64
     def test_nested_many_with_missing_attribute(self, user):
@@ -1948,7 +1974,7 @@ class TestNestedSchema:
 
     def test_nested_with_attribute_none(self):
         class InnerSchema(Schema):
-            bar = fields.Field()
+            bar = fields.Raw()
 
         class MySchema(Schema):
             foo = fields.Nested(InnerSchema)
@@ -1973,7 +1999,7 @@ class TestNestedSchema:
 
     def test_nested_none(self):
         class BlogDefaultSchema(Schema):
-            user = fields.Nested(UserSchema, default=0)
+            user = fields.Nested(UserSchema, dump_default=0)
 
         b = Blog("Just the default blog", user=None)
         data = BlogDefaultSchema().dump(b)
@@ -2011,7 +2037,7 @@ class TestNestedSchema:
 
     def test_exclude(self, blog):
         serialized = BlogSchemaExclude().dump(blog)
-        assert "uppername" not in serialized["user"].keys()
+        assert "uppername" not in serialized["user"]
 
     def test_list_field(self, blog):
         serialized = BlogSchema().dump(blog)
@@ -2028,7 +2054,7 @@ class TestNestedSchema:
         data = BlogSchema().load(in_data)
         collabs = data["collaborators"]
         assert len(collabs) == 2
-        assert all(type(each) == User for each in collabs)
+        assert all(type(each) is User for each in collabs)
         assert collabs[0].name == in_data["collaborators"][0]["name"]
 
     def test_nested_errors(self):
@@ -2078,7 +2104,7 @@ class TestNestedSchema:
     # regression test for https://github.com/marshmallow-code/marshmallow/issues/188
     def test_invalid_type_passed_to_nested_field(self):
         class InnerSchema(Schema):
-            foo = fields.Field()
+            foo = fields.Raw()
 
         class MySchema(Schema):
             inner = fields.Nested(InnerSchema, many=True)
@@ -2105,7 +2131,7 @@ class TestNestedSchema:
     # regression test for https://github.com/marshmallow-code/marshmallow/issues/298
     def test_all_errors_on_many_nested_field_with_validates_decorator(self):
         class Inner(Schema):
-            req = fields.Field(required=True)
+            req = fields.Raw(required=True)
 
         class Outer(Schema):
             inner = fields.Nested(Inner, many=True)
@@ -2133,7 +2159,7 @@ class TestNestedSchema:
         if unknown is None or unknown == RAISE:
             with pytest.raises(ValidationError) as exc:
                 ParentSchema().load(data)
-                assert exc.messages == {"child": {"extra": ["Unknown field."]}}
+            assert exc.value.messages == {"child": {"extra": ["Unknown field."]}}
         else:
             output = {
                 INCLUDE: {"child": {"num": 1, "extra": 1}},
@@ -2371,7 +2397,7 @@ class TestSelfReference:
 
 
 class RequiredUserSchema(Schema):
-    name = fields.Field(required=True)
+    name = fields.Raw(required=True)
 
 
 def test_serialization_with_required_field():
@@ -2497,13 +2523,14 @@ class TestContext:
         ser = CSchema()
         ser.context["info"] = "i like bikes"
         obj = {"inner": {}}
-        result = ser.dump(obj)
+        with pytest.warns(RemovedInMarshmallow4Warning):
+            result = ser.dump(obj)
         assert result["inner"]["likes_bikes"] is True
 
     # Regression test for https://github.com/marshmallow-code/marshmallow/issues/820
     def test_nested_list_fields_inherit_context(self):
         class InnerSchema(Schema):
-            foo = fields.Field()
+            foo = fields.Raw()
 
             @validates("foo")
             def validate_foo(self, value):
@@ -2524,7 +2551,7 @@ class TestContext:
     # Regression test for https://github.com/marshmallow-code/marshmallow/issues/820
     def test_nested_dict_fields_inherit_context(self):
         class InnerSchema(Schema):
-            foo = fields.Field()
+            foo = fields.Raw()
 
             @validates("foo")
             def validate_foo(self, value):
@@ -2549,10 +2576,12 @@ class TestContext:
                 raise NotImplementedError
 
         class InnerSchema(Schema):
-            foo = fields.Field()
+            foo = fields.Raw()
 
-        class OuterSchema(Schema):
-            inner = fields.Nested(InnerSchema(context={"unp": Unpicklable()}))
+        with pytest.warns(RemovedInMarshmallow4Warning):
+
+            class OuterSchema(Schema):
+                inner = fields.Nested(InnerSchema(context={"unp": Unpicklable()}))
 
         outer = OuterSchema()
         obj = {"inner": {"foo": 42}}
@@ -2570,9 +2599,11 @@ def test_serializer_can_specify_nested_object_as_attribute(blog):
 
 class TestFieldInheritance:
     def test_inherit_fields_from_schema_subclass(self):
-        expected = OrderedDict(
-            [("field_a", fields.Number()), ("field_b", fields.Number())]
-        )
+        with pytest.warns(ChangedInMarshmallow4Warning):
+            expected = {
+                "field_a": fields.Number(),
+                "field_b": fields.Number(),
+            }
 
         class SerializerA(Schema):
             field_a = expected["field_a"]
@@ -2583,9 +2614,11 @@ class TestFieldInheritance:
         assert SerializerB._declared_fields == expected
 
     def test_inherit_fields_from_non_schema_subclass(self):
-        expected = OrderedDict(
-            [("field_a", fields.Number()), ("field_b", fields.Number())]
-        )
+        with pytest.warns(ChangedInMarshmallow4Warning):
+            expected = {
+                "field_a": fields.Number(),
+                "field_b": fields.Number(),
+            }
 
         class PlainBaseClass:
             field_a = expected["field_a"]
@@ -2600,14 +2633,12 @@ class TestFieldInheritance:
         assert SerializerB2._declared_fields == expected
 
     def test_inheritance_follows_mro(self):
-        expected = OrderedDict(
-            [
-                ("field_a", fields.String()),
-                ("field_c", fields.String()),
-                ("field_b", fields.String()),
-                ("field_d", fields.String()),
-            ]
-        )
+        expected = {
+            "field_a": fields.String(),
+            "field_b": fields.String(),
+            "field_c": fields.String(),
+            "field_d": fields.String(),
+        }
         # Diamond inheritance graph
         # MRO: D -> B -> C -> A
 
@@ -2681,11 +2712,11 @@ class TestRequiredFields:
         allow_none_field = fields.Str(allow_none=True)
         allow_none_required_field = fields.Str(required=True, allow_none=True)
 
-    @pytest.fixture()
+    @pytest.fixture
     def string_schema(self):
         return self.StringSchema()
 
-    @pytest.fixture()
+    @pytest.fixture
     def data(self):
         return dict(
             required_field="foo",
@@ -2717,7 +2748,7 @@ class TestRequiredFields:
 
     def test_allow_none_custom_message(self, data):
         class MySchema(Schema):
-            allow_none_field = fields.Field(
+            allow_none_field = fields.Raw(
                 allow_none=False, error_messages={"null": "<custom>"}
             )
 
@@ -2733,14 +2764,14 @@ class TestDefaults:
         list_no_default = fields.List(fields.Str, allow_none=True)
         nested_no_default = fields.Nested(UserSchema, many=True, allow_none=True)
 
-        int_with_default = fields.Int(allow_none=True, default=42)
-        str_with_default = fields.Str(allow_none=True, default="foo")
+        int_with_default = fields.Int(allow_none=True, dump_default=42)
+        str_with_default = fields.Str(allow_none=True, dump_default="foo")
 
-    @pytest.fixture()
+    @pytest.fixture
     def schema(self):
         return self.MySchema()
 
-    @pytest.fixture()
+    @pytest.fixture
     def data(self):
         return dict(
             int_no_default=None,
@@ -2764,14 +2795,14 @@ class TestDefaults:
             # the missing key is not in the serialized result
             assert key not in result
             # the rest of the keys are in the result
-            assert all(k in result for k in d.keys())
+            assert all(k in result for k in d)
 
     def test_none_is_serialized_to_none(self, schema, data):
         errors = schema.validate(data)
         assert errors == {}
         result = schema.dump(data)
-        for key in data.keys():
-            msg = "result[{!r}] should be None".format(key)
+        for key in data:
+            msg = f"result[{key!r}] should be None"
             assert result[key] is None, msg
 
     def test_default_and_value_missing(self, schema, data):
@@ -2783,8 +2814,8 @@ class TestDefaults:
 
     def test_loading_none(self, schema, data):
         result = schema.load(data)
-        for key in data.keys():
-            result[key] is None
+        for key in data:
+            assert result[key] is None
 
     def test_missing_inputs_are_excluded_from_load_output(self, schema, data):
         for key in [
@@ -2799,7 +2830,7 @@ class TestDefaults:
             # the missing key is not in the deserialized result
             assert key not in result
             # the rest of the keys are in the result
-            assert all(k in result for k in d.keys())
+            assert all(k in result for k in d)
 
 
 class TestLoadOnly:
@@ -2812,11 +2843,11 @@ class TestLoadOnly:
         str_load_only = fields.String()
         str_regular = fields.String()
 
-    @pytest.fixture()
+    @pytest.fixture
     def schema(self):
         return self.MySchema()
 
-    @pytest.fixture()
+    @pytest.fixture
     def data(self):
         return dict(
             str_dump_only="Dump Only",
@@ -2880,3 +2911,50 @@ class TestFromDict:
         dumped = OSchema().dump({"foo": 42, "bar": 24})
         assert isinstance(dumped, OrderedDict)
         assert "bar" not in dumped
+
+
+def test_class_registry_returns_schema_type():
+    class DefinitelyUniqueSchema(Schema):
+        """
+        Just a schema
+        """
+
+    SchemaClass = class_registry.get_class(DefinitelyUniqueSchema.__name__)
+    assert SchemaClass is DefinitelyUniqueSchema
+
+
+@pytest.mark.parametrize("usage_location", ["meta", "init", "load"])
+def test_unknown_parameter_value_is_validated(usage_location):
+    class MySchema(Schema):
+        foo = fields.String()
+
+    with pytest.raises(  # noqa: PT012
+        ValueError,
+        match="Object 'badval' is not a valid value for the 'unknown' parameter",
+    ):
+        # Meta.unknown setting gets caught at class creation time, since that's when
+        # metaclass __new__ runs
+        if usage_location == "meta":
+
+            class SubSchema(MySchema):
+                class Meta:
+                    unknown = "badval"
+
+        # usages in init and load are caught at call time, as expected
+        elif usage_location == "init":
+            MySchema(unknown="badval")
+        else:
+            MySchema().load({"foo": "bar"}, unknown="badval")
+
+
+@pytest.mark.parametrize("dict_cls", (dict, OrderedDict))
+def test_set_dict_class(dict_cls):
+    """Demonstrate how to specify dict_class as class attribute"""
+
+    class MySchema(Schema):
+        dict_class = dict_cls
+        foo = fields.String()
+
+    result = MySchema().dump({"foo": "bar"})
+    assert result == {"foo": "bar"}
+    assert isinstance(result, dict_cls)
