@@ -1,15 +1,28 @@
 """Tests for field serialization."""
-from collections import namedtuple, OrderedDict
+
 import datetime as dt
-import itertools
 import decimal
+import ipaddress
+import itertools
+import math
 import uuid
+from collections import OrderedDict
+from typing import NamedTuple
 
 import pytest
 
-from marshmallow import Schema, fields, missing as missing_
+from marshmallow import Schema, fields
+from marshmallow import missing as missing_
+from marshmallow.warnings import (
+    ChangedInMarshmallow4Warning,
+    RemovedInMarshmallow4Warning,
+)
+from tests.base import ALL_FIELDS, DateEnum, GenderEnum, HairColorEnum, User, central
 
-from tests.base import User, ALL_FIELDS, central
+
+class Point(NamedTuple):
+    x: int
+    y: int
 
 
 class DateTimeList:
@@ -36,23 +49,26 @@ class TestFieldSerialization:
         ("value", "expected"), [(42, float(42)), (0, float(0)), (None, None)]
     )
     def test_number(self, value, expected, user):
-        field = fields.Number()
+        with pytest.warns(ChangedInMarshmallow4Warning):
+            field = fields.Number()
         user.age = value
         assert field.serialize("age", user) == expected
 
     def test_number_as_string(self, user):
         user.age = 42
-        field = fields.Number(as_string=True)
+        with pytest.warns(ChangedInMarshmallow4Warning):
+            field = fields.Number(as_string=True)
         assert field.serialize("age", user) == str(float(user.age))
 
     def test_number_as_string_passed_none(self, user):
         user.age = None
-        field = fields.Number(as_string=True, allow_none=True)
+        with pytest.warns(ChangedInMarshmallow4Warning):
+            field = fields.Number(as_string=True, allow_none=True)
         assert field.serialize("age", user) is None
 
     def test_function_field_passed_func(self, user):
         field = fields.Function(lambda obj: obj.name.upper())
-        assert "FOO" == field.serialize("key", user)
+        assert field.serialize("key", user) == "FOO"
 
     def test_function_field_passed_serialize_only_is_dump_only(self, user):
         field = fields.Function(serialize=lambda obj: obj.name.upper())
@@ -66,12 +82,12 @@ class TestFieldSerialization:
 
     def test_function_field_passed_serialize(self, user):
         field = fields.Function(serialize=lambda obj: obj.name.upper())
-        assert "FOO" == field.serialize("key", user)
+        assert field.serialize("key", user) == "FOO"
 
     # https://github.com/marshmallow-code/marshmallow/issues/395
     def test_function_field_does_not_swallow_attribute_error(self, user):
         def raise_error(obj):
-            raise AttributeError()
+            raise AttributeError
 
         field = fields.Function(serialize=raise_error)
         with pytest.raises(AttributeError):
@@ -107,11 +123,12 @@ class TestFieldSerialization:
         field = fields.Function(
             serialize=lambda obj, context: obj.name.upper() + context["key"]
         )
-        field.parent = Parent(context={"key": "BAR"})
-        assert "FOOBAR" == field.serialize("key", user)
+        with pytest.warns(RemovedInMarshmallow4Warning):
+            field.parent = Parent(context={"key": "BAR"})
+        assert field.serialize("key", user) == "FOOBAR"
 
     def test_function_field_passed_uncallable_object(self):
-        with pytest.raises(ValueError):
+        with pytest.raises(TypeError):
             fields.Function("uncallable")
 
     def test_integer_field(self, user):
@@ -124,14 +141,14 @@ class TestFieldSerialization:
 
     def test_integer_field_default(self, user):
         user.age = None
-        field = fields.Integer(default=0)
+        field = fields.Integer(dump_default=0)
         assert field.serialize("age", user) is None
         # missing
         assert field.serialize("age", {}) == 0
 
     def test_integer_field_default_set_to_none(self, user):
         user.age = None
-        field = fields.Integer(default=None)
+        field = fields.Integer(dump_default=None)
         assert field.serialize("age", user) is None
 
     def test_uuid_field(self, user):
@@ -143,6 +160,135 @@ class TestFieldSerialization:
         assert field.serialize("uuid1", user) == "12345678-1234-5678-1234-567812345678"
         assert field.serialize("uuid2", user) is None
 
+    def test_ip_address_field(self, user):
+        ipv4_string = "192.168.0.1"
+        ipv6_string = "ffff::ffff"
+        ipv6_exploded_string = ipaddress.ip_address("ffff::ffff").exploded
+
+        user.ipv4 = ipaddress.ip_address(ipv4_string)
+        user.ipv6 = ipaddress.ip_address(ipv6_string)
+        user.empty_ip = None
+
+        field_compressed = fields.IP()
+        assert isinstance(field_compressed.serialize("ipv4", user), str)
+        assert field_compressed.serialize("ipv4", user) == ipv4_string
+        assert isinstance(field_compressed.serialize("ipv6", user), str)
+        assert field_compressed.serialize("ipv6", user) == ipv6_string
+        assert field_compressed.serialize("empty_ip", user) is None
+
+        field_exploded = fields.IP(exploded=True)
+        assert isinstance(field_exploded.serialize("ipv6", user), str)
+        assert field_exploded.serialize("ipv6", user) == ipv6_exploded_string
+
+    def test_ipv4_address_field(self, user):
+        ipv4_string = "192.168.0.1"
+
+        user.ipv4 = ipaddress.ip_address(ipv4_string)
+        user.empty_ip = None
+
+        field = fields.IPv4()
+        assert isinstance(field.serialize("ipv4", user), str)
+        assert field.serialize("ipv4", user) == ipv4_string
+        assert field.serialize("empty_ip", user) is None
+
+    def test_ipv6_address_field(self, user):
+        ipv6_string = "ffff::ffff"
+        ipv6_exploded_string = ipaddress.ip_address("ffff::ffff").exploded
+
+        user.ipv6 = ipaddress.ip_address(ipv6_string)
+        user.empty_ip = None
+
+        field_compressed = fields.IPv6()
+        assert isinstance(field_compressed.serialize("ipv6", user), str)
+        assert field_compressed.serialize("ipv6", user) == ipv6_string
+        assert field_compressed.serialize("empty_ip", user) is None
+
+        field_exploded = fields.IPv6(exploded=True)
+        assert isinstance(field_exploded.serialize("ipv6", user), str)
+        assert field_exploded.serialize("ipv6", user) == ipv6_exploded_string
+
+    def test_ip_interface_field(self, user):
+        ipv4interface_string = "192.168.0.1/24"
+        ipv6interface_string = "ffff::ffff/128"
+        ipv6interface_exploded_string = ipaddress.ip_interface(
+            "ffff::ffff/128"
+        ).exploded
+
+        user.ipv4interface = ipaddress.ip_interface(ipv4interface_string)
+        user.ipv6interface = ipaddress.ip_interface(ipv6interface_string)
+        user.empty_ipinterface = None
+
+        field_compressed = fields.IPInterface()
+        assert isinstance(field_compressed.serialize("ipv4interface", user), str)
+        assert field_compressed.serialize("ipv4interface", user) == ipv4interface_string
+        assert isinstance(field_compressed.serialize("ipv6interface", user), str)
+        assert field_compressed.serialize("ipv6interface", user) == ipv6interface_string
+        assert field_compressed.serialize("empty_ipinterface", user) is None
+
+        field_exploded = fields.IPInterface(exploded=True)
+        assert isinstance(field_exploded.serialize("ipv6interface", user), str)
+        assert (
+            field_exploded.serialize("ipv6interface", user)
+            == ipv6interface_exploded_string
+        )
+
+    def test_ipv4_interface_field(self, user):
+        ipv4interface_string = "192.168.0.1/24"
+
+        user.ipv4interface = ipaddress.ip_interface(ipv4interface_string)
+        user.empty_ipinterface = None
+
+        field = fields.IPv4Interface()
+        assert isinstance(field.serialize("ipv4interface", user), str)
+        assert field.serialize("ipv4interface", user) == ipv4interface_string
+        assert field.serialize("empty_ipinterface", user) is None
+
+    def test_ipv6_interface_field(self, user):
+        ipv6interface_string = "ffff::ffff/128"
+        ipv6interface_exploded_string = ipaddress.ip_interface(
+            "ffff::ffff/128"
+        ).exploded
+
+        user.ipv6interface = ipaddress.ip_interface(ipv6interface_string)
+        user.empty_ipinterface = None
+
+        field_compressed = fields.IPv6Interface()
+        assert isinstance(field_compressed.serialize("ipv6interface", user), str)
+        assert field_compressed.serialize("ipv6interface", user) == ipv6interface_string
+        assert field_compressed.serialize("empty_ipinterface", user) is None
+
+        field_exploded = fields.IPv6Interface(exploded=True)
+        assert isinstance(field_exploded.serialize("ipv6interface", user), str)
+        assert (
+            field_exploded.serialize("ipv6interface", user)
+            == ipv6interface_exploded_string
+        )
+
+    def test_enum_field_by_symbol_serialization(self, user):
+        user.sex = GenderEnum.male
+        field = fields.Enum(GenderEnum)
+        assert field.serialize("sex", user) == "male"
+
+    def test_enum_field_by_value_true_serialization(self, user):
+        user.hair_color = HairColorEnum.black
+        field = fields.Enum(HairColorEnum, by_value=True)
+        assert field.serialize("hair_color", user) == "black hair"
+        user.sex = GenderEnum.male
+        field = fields.Enum(GenderEnum, by_value=True)
+        assert field.serialize("sex", user) == 1
+        user.some_date = DateEnum.date_1
+
+    def test_enum_field_by_value_field_serialization(self, user):
+        user.hair_color = HairColorEnum.black
+        field = fields.Enum(HairColorEnum, by_value=fields.String)
+        assert field.serialize("hair_color", user) == "black hair"
+        user.sex = GenderEnum.male
+        field = fields.Enum(GenderEnum, by_value=fields.Integer)
+        assert field.serialize("sex", user) == 1
+        user.some_date = DateEnum.date_1
+        field = fields.Enum(DateEnum, by_value=fields.Date(format="%d/%m/%Y"))
+        assert field.serialize("some_date", user) == "29/02/2004"
+
     def test_decimal_field(self, user):
         user.m1 = 12
         user.m2 = "12.355"
@@ -222,31 +368,38 @@ class TestFieldSerialization:
 
         m1s = field.serialize("m1", user)
         assert isinstance(m1s, decimal.Decimal)
-        assert m1s.is_qnan() and not m1s.is_signed()
+        assert m1s.is_qnan()
+        assert not m1s.is_signed()
 
         m2s = field.serialize("m2", user)
         assert isinstance(m2s, decimal.Decimal)
-        assert m2s.is_qnan() and not m2s.is_signed()
+        assert m2s.is_qnan()
+        assert not m2s.is_signed()
 
         m3s = field.serialize("m3", user)
         assert isinstance(m3s, decimal.Decimal)
-        assert m3s.is_qnan() and not m3s.is_signed()
+        assert m3s.is_qnan()
+        assert not m3s.is_signed()
 
         m4s = field.serialize("m4", user)
         assert isinstance(m4s, decimal.Decimal)
-        assert m4s.is_qnan() and not m4s.is_signed()
+        assert m4s.is_qnan()
+        assert not m4s.is_signed()
 
         m5s = field.serialize("m5", user)
         assert isinstance(m5s, decimal.Decimal)
-        assert m5s.is_infinite() and m5s.is_signed()
+        assert m5s.is_infinite()
+        assert m5s.is_signed()
 
         m6s = field.serialize("m6", user)
         assert isinstance(m6s, decimal.Decimal)
-        assert m6s.is_infinite() and not m6s.is_signed()
+        assert m6s.is_infinite()
+        assert not m6s.is_signed()
 
         m7s = field.serialize("m7", user)
         assert isinstance(m7s, decimal.Decimal)
-        assert m7s.is_zero() and m7s.is_signed()
+        assert m7s.is_zero()
+        assert m7s.is_signed()
 
         field = fields.Decimal(as_string=True, allow_nan=True)
 
@@ -269,7 +422,8 @@ class TestFieldSerialization:
 
         m7s = field.serialize("m7", user)
         assert isinstance(m7s, decimal.Decimal)
-        assert m7s.is_zero() and m7s.is_signed()
+        assert m7s.is_zero()
+        assert m7s.is_signed()
 
     def test_decimal_field_fixed_point_representation(self, user):
         """
@@ -304,10 +458,6 @@ class TestFieldSerialization:
         assert field.serialize("falsy", user) is False
         assert field.serialize("none", user) is None
 
-    def test_function_with_uncallable_param(self):
-        with pytest.raises(ValueError):
-            fields.Function("uncallable")
-
     def test_email_field_serialize_none(self, user):
         user.email = None
         field = fields.Email()
@@ -318,16 +468,14 @@ class TestFieldSerialization:
         field = fields.Dict()
         assert field.serialize("various_data", user) is None
 
-    def test_dict_field_invalid_dict_but_okay(self, user):
-        user.various_data = "okaydict"
-        field = fields.Dict()
-        field.serialize("various_data", user)
-        assert field.serialize("various_data", user) == "okaydict"
-
     def test_dict_field_serialize(self, user):
         user.various_data = {"foo": "bar"}
         field = fields.Dict()
-        assert field.serialize("various_data", user) == {"foo": "bar"}
+        dump = field.serialize("various_data", user)
+        assert dump == {"foo": "bar"}
+        # Check dump is a distinct object
+        dump["foo"] = "baz"
+        assert user.various_data["foo"] == "bar"
 
     def test_dict_field_serialize_ordereddict(self, user):
         user.various_data = OrderedDict([("foo", "bar"), ("bar", "baz")])
@@ -360,9 +508,8 @@ class TestFieldSerialization:
         class BadSerializer(Schema):
             bad_field = fields.Method("invalid")
 
-        u = User("Foo")
-        with pytest.raises(ValueError):
-            BadSerializer().dump(u)
+        with pytest.raises(AttributeError):
+            BadSerializer()
 
     def test_method_field_passed_serialize_only_is_dump_only(self, user):
         field = fields.Method(serialize="method")
@@ -379,9 +526,8 @@ class TestFieldSerialization:
             foo = "not callable"
             bad_field = fields.Method("foo")
 
-        u = User("Foo")
-        with pytest.raises(ValueError):
-            BadSerializer().dump(u)
+        with pytest.raises(TypeError):
+            BadSerializer()
 
     # https://github.com/marshmallow-code/marshmallow/issues/395
     def test_method_field_does_not_swallow_attribute_error(self):
@@ -389,7 +535,7 @@ class TestFieldSerialization:
             mfield = fields.Method("raise_error")
 
             def raise_error(self, obj):
-                raise AttributeError()
+                raise AttributeError
 
         with pytest.raises(AttributeError):
             MySchema().dump({})
@@ -411,10 +557,10 @@ class TestFieldSerialization:
 
     def test_serialize_with_data_key_as_empty_string(self):
         class MySchema(Schema):
-            name = fields.Field(data_key="")
+            name = fields.Raw(data_key="")
 
         schema = MySchema()
-        schema.dump({"name": "Grace"}) == {"": "Grace"}
+        assert schema.dump({"name": "Grace"}) == {"": "Grace"}
 
     def test_serialize_with_attribute_and_data_key_uses_data_key(self):
         class ConfusedDumpToAndAttributeSerializer(Schema):
@@ -441,7 +587,7 @@ class TestFieldSerialization:
                 "Sun, 10 Nov 2013 01:23:45 +0000",
             ),
             (
-                central.localize(dt.datetime(2013, 11, 10, 1, 23, 45), is_dst=False),
+                dt.datetime(2013, 11, 10, 1, 23, 45, tzinfo=central),
                 "Sun, 10 Nov 2013 01:23:45 -0600",
             ),
         ],
@@ -450,6 +596,38 @@ class TestFieldSerialization:
         field = fields.DateTime(format=fmt)
         assert field.serialize("d", {"d": value}) == expected
 
+    @pytest.mark.parametrize(
+        ("fmt", "value", "expected"),
+        [
+            ("timestamp", dt.datetime(1970, 1, 1), 0),
+            ("timestamp", dt.datetime(2013, 11, 10, 0, 23, 45), 1384043025),
+            (
+                "timestamp",
+                dt.datetime(2013, 11, 10, 0, 23, 45, tzinfo=dt.timezone.utc),
+                1384043025,
+            ),
+            (
+                "timestamp",
+                dt.datetime(2013, 11, 10, 0, 23, 45, tzinfo=central),
+                1384064625,
+            ),
+            ("timestamp_ms", dt.datetime(2013, 11, 10, 0, 23, 45), 1384043025000),
+            (
+                "timestamp_ms",
+                dt.datetime(2013, 11, 10, 0, 23, 45, tzinfo=dt.timezone.utc),
+                1384043025000,
+            ),
+            (
+                "timestamp_ms",
+                dt.datetime(2013, 11, 10, 0, 23, 45, tzinfo=central),
+                1384064625000,
+            ),
+        ],
+    )
+    def test_datetime_field_timestamp(self, fmt, value, expected):
+        field = fields.DateTime(format=fmt)
+        assert field.serialize("d", {"d": value}) == expected
+
     @pytest.mark.parametrize("fmt", ["iso", "iso8601", None])
     @pytest.mark.parametrize(
         ("value", "expected"),
@@ -464,7 +642,7 @@ class TestFieldSerialization:
                 "2013-11-10T01:23:45+00:00",
             ),
             (
-                central.localize(dt.datetime(2013, 11, 10, 1, 23, 45), is_dst=False),
+                dt.datetime(2013, 11, 10, 1, 23, 45, tzinfo=central),
                 "2013-11-10T01:23:45-06:00",
             ),
         ],
@@ -478,9 +656,9 @@ class TestFieldSerialization:
         assert field.serialize("d", {"d": value}) == expected
 
     def test_datetime_field_format(self, user):
-        format = "%Y-%m-%d"
-        field = fields.DateTime(format=format)
-        assert field.serialize("created", user) == user.created.strftime(format)
+        datetimeformat = "%Y-%m-%d"
+        field = fields.DateTime(format=datetimeformat)
+        assert field.serialize("created", user) == user.created.strftime(datetimeformat)
 
     def test_string_field(self):
         field = fields.String()
@@ -491,7 +669,7 @@ class TestFieldSerialization:
         assert field.serialize("name", user) is None
 
     def test_string_field_default_to_empty_string(self, user):
-        field = fields.String(default="")
+        field = fields.String(dump_default="")
         assert field.serialize("notfound", {}) == ""
 
     def test_time_field(self, user):
@@ -502,6 +680,28 @@ class TestFieldSerialization:
         user.time_registered = None
         assert field.serialize("time_registered", user) is None
 
+    @pytest.mark.parametrize("fmt", ["iso", "iso8601", None])
+    @pytest.mark.parametrize(
+        ("value", "expected"),
+        [
+            (dt.time(1, 23, 45), "01:23:45"),
+            (dt.time(1, 23, 45, 123000), "01:23:45.123000"),
+            (dt.time(1, 23, 45, 123456), "01:23:45.123456"),
+        ],
+    )
+    def test_time_field_iso8601(self, fmt, value, expected):
+        if fmt is None:
+            # Test default is ISO
+            field = fields.Time()
+        else:
+            field = fields.Time(format=fmt)
+        assert field.serialize("d", {"d": value}) == expected
+
+    def test_time_field_format(self, user):
+        fmt = "%H:%M:%S"
+        field = fields.Time(format=fmt)
+        assert field.serialize("birthtime", user) == user.birthtime.strftime(fmt)
+
     def test_date_field(self, user):
         field = fields.Date()
         assert field.serialize("birthdate", user) == user.birthdate.isoformat()
@@ -582,16 +782,77 @@ class TestFieldSerialization:
         field = fields.TimeDelta(fields.TimeDelta.MILLISECONDS)
         assert field.serialize("d6", user) == d6_seconds * 1000 + 1
         field = fields.TimeDelta(fields.TimeDelta.MICROSECONDS)
-        assert field.serialize("d6", user) == d6_seconds * 10 ** 6 + 1000 + 1
+        assert field.serialize("d6", user) == d6_seconds * 10**6 + 1000 + 1
 
         user.d7 = None
         assert field.serialize("d7", user) is None
 
+        # https://github.com/marshmallow-code/marshmallow/issues/1856
+        user.d8 = dt.timedelta(milliseconds=345)
+        field = fields.TimeDelta(fields.TimeDelta.MILLISECONDS)
+        assert field.serialize("d8", user) == 345
+
+        user.d9 = dt.timedelta(milliseconds=1999)
+        field = fields.TimeDelta(fields.TimeDelta.SECONDS)
+        assert field.serialize("d9", user) == 1
+
+        user.d10 = dt.timedelta(
+            weeks=1,
+            days=6,
+            hours=2,
+            minutes=5,
+            seconds=51,
+            milliseconds=10,
+            microseconds=742,
+        )
+
+        field = fields.TimeDelta(fields.TimeDelta.MICROSECONDS, float)
+        unit_value = dt.timedelta(microseconds=1).total_seconds()
+        assert math.isclose(
+            field.serialize("d10", user), user.d10.total_seconds() / unit_value
+        )
+
+        field = fields.TimeDelta(fields.TimeDelta.MILLISECONDS, float)
+        unit_value = dt.timedelta(milliseconds=1).total_seconds()
+        assert math.isclose(
+            field.serialize("d10", user), user.d10.total_seconds() / unit_value
+        )
+
+        field = fields.TimeDelta(fields.TimeDelta.SECONDS, float)
+        assert math.isclose(field.serialize("d10", user), user.d10.total_seconds())
+
+        field = fields.TimeDelta(fields.TimeDelta.MINUTES, float)
+        unit_value = dt.timedelta(minutes=1).total_seconds()
+        assert math.isclose(
+            field.serialize("d10", user), user.d10.total_seconds() / unit_value
+        )
+
+        field = fields.TimeDelta(fields.TimeDelta.HOURS, float)
+        unit_value = dt.timedelta(hours=1).total_seconds()
+        assert math.isclose(
+            field.serialize("d10", user), user.d10.total_seconds() / unit_value
+        )
+
+        field = fields.TimeDelta(fields.TimeDelta.DAYS, float)
+        unit_value = dt.timedelta(days=1).total_seconds()
+        assert math.isclose(
+            field.serialize("d10", user), user.d10.total_seconds() / unit_value
+        )
+
+        field = fields.TimeDelta(fields.TimeDelta.WEEKS, float)
+        unit_value = dt.timedelta(weeks=1).total_seconds()
+        assert math.isclose(
+            field.serialize("d10", user), user.d10.total_seconds() / unit_value
+        )
+
+        with pytest.raises(ValueError):
+            fields.TimeDelta(fields.TimeDelta.SECONDS, str)
+
     def test_datetime_list_field(self):
-        obj = DateTimeList([dt.datetime.utcnow(), dt.datetime.now()])
+        obj = DateTimeList([dt.datetime.now(dt.timezone.utc), dt.datetime.now()])
         field = fields.List(fields.DateTime)
         result = field.serialize("dtimes", obj)
-        assert all([type(each) == str for each in result])
+        assert all(type(each) is str for each in result)
 
     def test_list_field_serialize_none_returns_none(self):
         obj = DateTimeList(None)
@@ -600,7 +861,7 @@ class TestFieldSerialization:
 
     def test_list_field_work_with_generator_single_value(self):
         def custom_generator():
-            yield dt.datetime.utcnow()
+            yield dt.datetime.now(dt.timezone.utc)
 
         obj = DateTimeList(custom_generator())
         field = fields.List(fields.DateTime)
@@ -609,14 +870,14 @@ class TestFieldSerialization:
 
     def test_list_field_work_with_generators_multiple_values(self):
         def custom_generator():
-            yield from [dt.datetime.utcnow(), dt.datetime.now()]
+            yield from [dt.datetime.now(dt.timezone.utc), dt.datetime.now()]
 
         obj = DateTimeList(custom_generator())
         field = fields.List(fields.DateTime)
         result = field.serialize("dtimes", obj)
         assert len(result) == 2
 
-    def test_list_field_work_with_generators_empty_generator_returns_none_for_every_non_returning_yield_statement(  # noqa: B950
+    def test_list_field_work_with_generators_empty_generator_returns_none_for_every_non_returning_yield_statement(
         self,
     ):
         def custom_generator():
@@ -671,11 +932,11 @@ class TestFieldSerialization:
             fields.List(ASchema)
 
     def test_datetime_integer_tuple_field(self):
-        obj = DateTimeIntegerTuple((dt.datetime.utcnow(), 42))
+        obj = DateTimeIntegerTuple((dt.datetime.now(dt.timezone.utc), 42))
         field = fields.Tuple([fields.DateTime, fields.Integer])
         result = field.serialize("dtime_int", obj)
-        assert type(result[0]) == str
-        assert type(result[1]) == int
+        assert type(result[0]) is str
+        assert type(result[1]) is int
 
     def test_tuple_field_serialize_none_returns_none(self):
         obj = DateTimeIntegerTuple(None)
@@ -698,7 +959,7 @@ class TestFieldSerialization:
             fields.Tuple([ASchema])
 
     def test_serialize_does_not_apply_validators(self, user):
-        field = fields.Field(validate=lambda x: False)
+        field = fields.Raw(validate=lambda x: False)
         # No validation error raised
         assert field.serialize("age", user) == user.age
 
@@ -732,7 +993,7 @@ class TestSchemaSerialization:
     def test_serialize_with_missing_param_value(self):
         class AliasingUserSerializer(Schema):
             name = fields.String()
-            birthdate = fields.DateTime(default=dt.datetime(2017, 9, 29))
+            birthdate = fields.DateTime(dump_default=dt.datetime(2017, 9, 29))
 
         data = {"name": "Mick"}
         result = AliasingUserSerializer().dump(data)
@@ -742,7 +1003,7 @@ class TestSchemaSerialization:
     def test_serialize_with_missing_param_callable(self):
         class AliasingUserSerializer(Schema):
             name = fields.String()
-            birthdate = fields.DateTime(default=lambda: dt.datetime(2017, 9, 29))
+            birthdate = fields.DateTime(dump_default=lambda: dt.datetime(2017, 9, 29))
 
         data = {"name": "Mick"}
         result = AliasingUserSerializer().dump(data)
@@ -751,9 +1012,7 @@ class TestSchemaSerialization:
 
 
 def test_serializing_named_tuple():
-    Point = namedtuple("Point", ["x", "y"])
-
-    field = fields.Field()
+    field = fields.Raw()
 
     p = Point(x=4, y=2)
 
@@ -761,7 +1020,6 @@ def test_serializing_named_tuple():
 
 
 def test_serializing_named_tuple_with_meta():
-    Point = namedtuple("Point", ["x", "y"])
     p = Point(x=4, y=2)
 
     class PointSerializer(Schema):
@@ -775,12 +1033,12 @@ def test_serializing_named_tuple_with_meta():
 
 def test_serializing_slice():
     values = [{"value": value} for value in range(5)]
-    slice = itertools.islice(values, None)
+    sliced = itertools.islice(values, None)
 
     class ValueSchema(Schema):
         value = fields.Int()
 
-    serialized = ValueSchema(many=True).dump(slice)
+    serialized = ValueSchema(many=True).dump(sliced)
     assert serialized == values
 
 
