@@ -1,9 +1,10 @@
 """Tests for marshmallow.validate"""
 
 import re
+
 import pytest
 
-from marshmallow import validate, ValidationError
+from marshmallow import ValidationError, validate
 
 
 @pytest.mark.parametrize(
@@ -28,6 +29,9 @@ from marshmallow import validate, ValidationError
         "http://www.example.com:8000/foo",
         "http://user@example.com",
         "http://user:pass@example.com",
+        "http://:pass@example.com",
+        "http://@example.com",
+        "http://AZaz09-._~%2A!$&'()*+,;=:@example.com",
     ],
 )
 def test_url_absolute_valid(valid_url):
@@ -41,6 +45,7 @@ def test_url_absolute_valid(valid_url):
         "http:///example.com/",
         "https:///example.com/",
         "https://example.org\\",
+        "https://example.org\n",
         "ftp:///example.com/",
         "ftps:///example.com/",
         "http//example.org",
@@ -56,6 +61,12 @@ def test_url_absolute_valid(valid_url):
         " ",
         "",
         None,
+        "http://user@pass@example.com",
+        "http://@pass@example.com",
+        "http://@@example.com",
+        "http://^@example.com",
+        "http://%0G@example.com",
+        "http://%@example.com",
     ],
 )
 def test_url_absolute_invalid(invalid_url):
@@ -74,6 +85,9 @@ def test_url_absolute_invalid(invalid_url):
         "http://example.com/./icons/logo.gif",
         "ftp://example.com/../../../../g",
         "http://example.com/g?y/./x",
+        "/foo/bar",
+        "/foo?bar",
+        "/foo?bar#baz",
     ],
 )
 def test_url_relative_valid(valid_url):
@@ -81,10 +95,11 @@ def test_url_relative_valid(valid_url):
     assert validator(valid_url) == valid_url
 
 
-@pytest.mark.parametrize(  # noqa: W605
+@pytest.mark.parametrize(
     "invalid_url",
     [
         "http//example.org",
+        "http://example.org\n",
         "suppliers.html",
         "../icons/logo.gif",
         "icons/logo.gif",
@@ -102,6 +117,48 @@ def test_url_relative_invalid(invalid_url):
         validator(invalid_url)
 
 
+@pytest.mark.parametrize(
+    "valid_url",
+    [
+        "/foo/bar",
+        "/foo?bar",
+        "?bar",
+        "/foo?bar#baz",
+    ],
+)
+def test_url_relative_only_valid(valid_url):
+    validator = validate.URL(relative=True, absolute=False)
+    assert validator(valid_url) == valid_url
+
+
+@pytest.mark.parametrize(
+    "invalid_url",
+    [
+        "http//example.org",
+        "http://example.org\n",
+        "suppliers.html",
+        "../icons/logo.gif",
+        "icons/logo.gif",
+        "../.../g",
+        "...",
+        "\\",
+        " ",
+        "",
+        "http://example.org",
+        "http://123.45.67.8/",
+        "http://example.com/foo/bar/../baz",
+        "https://example.com/../icons/logo.gif",
+        "http://example.com/./icons/logo.gif",
+        "ftp://example.com/../../../../g",
+        "http://example.com/g?y/./x",
+    ],
+)
+def test_url_relative_only_invalid(invalid_url):
+    validator = validate.URL(relative=True, absolute=False)
+    with pytest.raises(ValidationError):
+        validator(invalid_url)
+
+
 @pytest.mark.parametrize(
     "valid_url",
     [
@@ -123,6 +180,7 @@ def test_url_dont_require_tld_valid(valid_url):
     "invalid_url",
     [
         "http//example",
+        "http://example\n",
         "http://.example.org",
         "http:///foo/bar",
         "http:// /foo/bar",
@@ -147,6 +205,40 @@ def test_url_custom_scheme():
     assert validator(url) == url
 
 
+@pytest.mark.parametrize(
+    "valid_url",
+    (
+        "file:///tmp/tmp1234",
+        "file://localhost/tmp/tmp1234",
+        "file:///C:/Users/test/file.txt",
+        "file://localhost/C:/Program%20Files/file.exe",
+        "file:///home/user/documents/test.pdf",
+        "file:///tmp/test%20file.txt",
+        "file:///",
+        "file://localhost/",
+    ),
+)
+def test_url_accepts_valid_file_urls(valid_url):
+    validator = validate.URL(schemes={"file"})
+    assert validator(valid_url) == valid_url
+
+
+@pytest.mark.parametrize(
+    "invalid_url",
+    (
+        "file://",
+        "file:/tmp/file.txt",
+        "file:tmp/file.txt",
+        "file://hostname/path",
+        "file:///tmp/test file.txt",
+    ),
+)
+def test_url_rejects_invalid_file_urls(invalid_url):
+    validator = validate.URL(schemes={"file"})
+    with pytest.raises(ValidationError, match="Not a valid URL."):
+        assert validator(invalid_url)
+
+
 def test_url_relative_and_custom_schemes():
     validator = validate.URL(relative=True)
     # By default, ws not allowed
@@ -167,10 +259,21 @@ def test_url_custom_message():
 def test_url_repr():
     assert repr(
         validate.URL(relative=False, error=None)
-    ) == "<URL(relative=False, error={!r})>".format("Not a valid URL.")
+    ) == "<URL(relative=False, absolute=True, error={!r})>".format("Not a valid URL.")
     assert repr(
         validate.URL(relative=True, error="foo")
-    ) == "<URL(relative=True, error={!r})>".format("foo")
+    ) == "<URL(relative=True, absolute=True, error={!r})>".format("foo")
+    assert repr(
+        validate.URL(relative=True, absolute=False, error="foo")
+    ) == "<URL(relative=True, absolute=False, error={!r})>".format("foo")
+
+
+def test_url_rejects_invalid_relative_usage():
+    with pytest.raises(
+        ValueError,
+        match="URL validation cannot set both relative and absolute to False",
+    ):
+        validate.URL(relative=False, absolute=False)
 
 
 @pytest.mark.parametrize(
@@ -197,6 +300,8 @@ def test_email_valid(valid_email):
 @pytest.mark.parametrize(
     "invalid_email",
     [
+        "niceandsimple\n@example.com",
+        "NiCeAnDsImPlE@eXaMpLe.CoM\n",
         'a"b(c)d,e:f;g<h>i[j\\k]l@example.com',
         'just"not"right@example.com',
         'this is"not\allowed@example.com',
@@ -286,14 +391,17 @@ def test_range_repr():
                 min=None, max=None, error=None, min_inclusive=True, max_inclusive=True
             )
         )
-        == "<Range(min=None, max=None, min_inclusive=True, max_inclusive=True, error=None)>"  # noqa: B950
+        == "<Range(min=None, max=None, min_inclusive=True, max_inclusive=True, error=None)>"
     )
-    assert repr(
-        validate.Range(
-            min=1, max=3, error="foo", min_inclusive=False, max_inclusive=False
+    assert (
+        repr(
+            validate.Range(
+                min=1, max=3, error="foo", min_inclusive=False, max_inclusive=False
+            )
+        )
+        == "<Range(min=1, max=3, min_inclusive=False, max_inclusive=False, error={!r})>".format(
+            "foo"
         )
-    ) == "<Range(min=1, max=3, min_inclusive=False, max_inclusive=False, error={!r})>".format(  # noqa: B950
-        "foo"
     )
 
 
@@ -347,12 +455,12 @@ def test_length_equal():
         validate.Length(equal=2)("foo")
     with pytest.raises(ValidationError):
         validate.Length(equal=2)([1, 2, 3])
-
-    with pytest.raises(ValueError):
+    error_message = "The `equal` parameter was provided, maximum or minimum parameter must not be provided"
+    with pytest.raises(ValueError, match=error_message):
         validate.Length(1, None, equal=3)("foo")
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match=error_message):
         validate.Length(None, 5, equal=3)("foo")
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match=error_message):
         validate.Length(1, 5, equal=3)("foo")
 
 
@@ -752,3 +860,158 @@ def test_containsonly_repr():
     ) == "<ContainsOnly(choices=[1, 2, 3], labels={!r}, error={!r})>".format(
         ["a", "b", "c"], "foo"
     )
+
+
+def test_containsnoneof_error_message():
+    with pytest.raises(
+        ValidationError, match="One or more of the choices you made was in: 1"
+    ):
+        validate.ContainsNoneOf([1])([1])
+
+    with pytest.raises(
+        ValidationError, match="One or more of the choices you made was in: 1, 2, 3"
+    ):
+        validate.ContainsNoneOf([1, 2, 3])([1])
+
+    with pytest.raises(
+        ValidationError, match="One or more of the choices you made was in: one, two"
+    ):
+        validate.ContainsNoneOf(["one", "two"])(["one"])
+
+    with pytest.raises(
+        ValidationError, match="One or more of the choices you made was in: @, !, &, ?"
+    ):
+        validate.ContainsNoneOf("@!&?")("@")
+
+
+def test_containsnoneof_in_list():
+    assert validate.ContainsNoneOf([])([]) == []
+    assert validate.ContainsNoneOf([])([1, 2, 3]) == [1, 2, 3]
+    assert validate.ContainsNoneOf([4])([1, 2, 3]) == [1, 2, 3]
+    assert validate.ContainsNoneOf([2])([1, 3, 4]) == [1, 3, 4]
+    assert validate.ContainsNoneOf([1, 2, 3])([4]) == [4]
+    assert validate.ContainsNoneOf([4])([1, 1, 1, 1]) == [1, 1, 1, 1]
+
+    with pytest.raises(ValidationError):
+        validate.ContainsNoneOf([1])([1, 2, 3])
+
+    with pytest.raises(ValidationError):
+        validate.ContainsNoneOf([1, 1, 1])([1, 2, 3])
+
+    with pytest.raises(ValidationError):
+        validate.ContainsNoneOf([1, 2])([1, 2])
+
+    with pytest.raises(ValidationError):
+        validate.ContainsNoneOf([1])([1, 1, 1, 1])
+
+
+def test_containsnoneof_unhashable_types():
+    assert validate.ContainsNoneOf([[1], [2], [3]])([]) == []
+    assert validate.ContainsNoneOf([[1], [2], [3]])([[4]]) == [[4]]
+    assert validate.ContainsNoneOf([[1], [2], [3]])([[4], [4]]) == [[4], [4]]
+    assert validate.ContainsNoneOf([[1], [2], [3]])([[4], [5]]) == [[4], [5]]
+
+    with pytest.raises(ValidationError):
+        validate.ContainsNoneOf([[1], [2], [3]])([[1]])
+
+    with pytest.raises(ValidationError):
+        validate.ContainsNoneOf([[1], [2], [3]])([[1], [2]])
+
+    with pytest.raises(ValidationError):
+        validate.ContainsNoneOf([[1], [2], [3]])([[2], [1]])
+
+    with pytest.raises(ValidationError):
+        validate.ContainsNoneOf([[1], [2], [3]])([[1], [2], [3]])
+
+    with pytest.raises(ValidationError):
+        validate.ContainsNoneOf([[1], [2], [3]])([[3], [2], [1]])
+
+    with pytest.raises(ValidationError):
+        validate.ContainsNoneOf([[1], [2], [3]])([[2], [3], [1]])
+
+
+def test_containsnoneof_in_tuple():
+    assert validate.ContainsNoneOf(())(()) == ()
+    assert validate.ContainsNoneOf(())((1, 2, 3)) == (1, 2, 3)
+    assert validate.ContainsNoneOf((4,))((1, 2, 3)) == (1, 2, 3)
+    assert validate.ContainsNoneOf((2,))((1, 3, 4)) == (1, 3, 4)
+    assert validate.ContainsNoneOf((1, 2, 3))((4,)) == (4,)
+    assert validate.ContainsNoneOf((4,))((1, 1, 1, 1)) == (1, 1, 1, 1)
+
+    with pytest.raises(ValidationError):
+        validate.ContainsNoneOf((1,))((1, 2, 3))
+
+    with pytest.raises(ValidationError):
+        validate.ContainsNoneOf((1, 1, 1))((1, 2, 3))
+
+    with pytest.raises(ValidationError):
+        validate.ContainsNoneOf((1, 2))((1, 2))
+
+    with pytest.raises(ValidationError):
+        validate.ContainsNoneOf((1,))((1, 1, 1, 1))
+
+
+def test_containsnoneof_in_string():
+    assert validate.ContainsNoneOf("")("") == ""
+    assert validate.ContainsNoneOf("")("abc") == "abc"
+    assert validate.ContainsNoneOf("d")("abc") == "abc"
+    assert validate.ContainsNoneOf("b")("acd") == "acd"
+    assert validate.ContainsNoneOf("abc")("d") == "d"
+    assert validate.ContainsNoneOf("d")("aaaa") == "aaaa"
+
+    with pytest.raises(ValidationError):
+        validate.ContainsNoneOf("a")("abc")
+
+    with pytest.raises(ValidationError):
+        validate.ContainsNoneOf("aaa")("abc")
+
+    with pytest.raises(ValidationError):
+        validate.ContainsNoneOf("ab")("ab")
+
+    with pytest.raises(ValidationError):
+        validate.ContainsNoneOf("a")("aaaa")
+
+
+def test_containsnoneof_custom_message():
+    validator = validate.ContainsNoneOf(
+        [1, 2, 3], error="{input} was in the banned list: {values}"
+    )
+    expected = "1 was in the banned list: 1, 2, 3"
+    with pytest.raises(ValidationError, match=expected):
+        validator([1])
+
+
+def test_containsnoneof_mixing_types():
+    with pytest.raises(ValidationError):
+        validate.ContainsNoneOf("abc")(["a"])
+
+    with pytest.raises(ValidationError):
+        validate.ContainsNoneOf(["a", "b", "c"])("a")
+
+    with pytest.raises(ValidationError):
+        validate.ContainsNoneOf((1, 2, 3))([1])
+
+    with pytest.raises(ValidationError):
+        validate.ContainsNoneOf([1, 2, 3])((1,))
+
+
+def is_even(value):
+    if value % 2 != 0:
+        raise ValidationError("Not an even value.")
+
+
+def test_and():
+    validator = validate.And(validate.Range(min=0), is_even)
+    assert validator(2)
+    with pytest.raises(ValidationError) as excinfo:
+        validator(-1)
+    errors = excinfo.value.messages
+    assert errors == ["Must be greater than or equal to 0.", "Not an even value."]
+
+    validator_with_composition = validate.And(validator, validate.Range(max=6))
+    assert validator_with_composition(4)
+    with pytest.raises(ValidationError) as excinfo:
+        validator_with_composition(7)
+
+    errors = excinfo.value.messages
+    assert errors == ["Not an even value.", "Must be less than or equal to 6."]
